

extensions [ gis
             profiler 
  ]

breed [ farmers farmer 
  ]

farmers-own [             ; farmers are added that represent the characteristics of a potato field (cluster of grid-cells)
  field-id                
  field
  field-size
  cultivar-field
  spraying?
]

patches-own [
  field-nr
  potato?
  cultivar
  fungicides?
  escape-frac  
  in-inf? 
  infection-level-total 
  infection-level-0        ; variables related to wild type
  l0-0
  l1-0 
  l2-0 
  l3-0 
  l4-0 
  l5-0 
  inf-0 
  nlinf-0 
  inf-rate-0
  spore-production-0
  spores-dispersed-0
  total-spores-0  
  initial-day-0  
  infected-0?
  inf-efficiency-0
    
  infection-level-1       ; variables related to virulent strain
  l0-1
  l1-1 
  l2-1 
  l3-1 
  l4-1 
  l5-1 
  inf-1 
  nlinf-1 
  inf-rate-1
  spore-production-1    
  virulent-spores-1
  spores-dispersed-1
  total-spores-1
  initial-day-1
  infected-1?  
  inf-efficiency-1    
  
  lai
  yield
  crop-emergence
  rgr              
  max-lai
  tuber-growth-rate
  end-tub
  lue
  eff-fungicides
  application-day
  fungicide-appl
  growth-period
  sum-temp 
  broken-resistance? 
  lai-rate
  yield-rate
]

globals [  
  
; MOVED TO INTERFACE
;  lai-initial
;  harvest-date
;  crop-emergence-avg   
;  LUE-sus                      ; light use efficiency sus. variety
;  LUE-res                      ; light use efficiency res. variety
;  max-lai-susceptible
;  max-lai-resistant
;  rg-lai                       ; leaf growth rate
;  rd-lai                       ; leaf death rate
;  wind-speed_               
;  frac-initial-infected        
;  initial-inf-surface-area
;  mutfrac                      ; mutation fraction
;  lesion-size                  ; area of one spore lesion
;  si                           ; sporulation intensity
;  spore-survival               ; spore survival fraction
;  cur-eff                      ; effect curarive fungicides
;  dep-eff                      ; deposition efficiency
;  rg-lesions                   ; lesion growth rate
;  inf-efficiency-std
                               
  potato-landscape              ;gis variables for load-map
  field-landscape
  
  potato-patches
  nr-potato-patches
  res-patches
  sus-patches
  nr-sus-patches
  nr-res-patches
  nr-sus-std-patches
  nr-sus-fungi-patches 
  
  color-sus-cv
  color-res-cv
  color-non-potato
  growing-potatoes
  
  year-counter                  ;model parameters 
  first-year
  patchsize 
  blight-day-counter
  start-year                    
  end-year
  day-counter 
  day
  month
  DMC
  application-interval
  day-first-application
  alfa
  lec                          ; light extinction coefficient
  temp-sum-maxlai
  temp-sum-tub-init
  beta
  inf-efficiency-res
  c-karman
  dep-vel
  wind-direction
  burn-level
  eff-fungicides-min
  eff-fungicides-max
  t50
  growing-degrees  
  cx200
  cx400
  cx600
  cx800
  cx1000
  tot-dispersed-spores
                               
  mean-yield                   ;model output  
  mean-yield-sus
  mean-yield-sus-std
  mean-yield-sus-fungi
  mean-yield-res
  mean-yield-res-std
  mean-yield-res-fungi
  
  infected-0-sum
  infected-1-sum
  infected-tot>0%
  infected-tot>1%              ; disease incidence
  infected-tot>5%
  infected-res>0%              ; infected resistant fields (resistance breakdown)
  infected-res>1%               
  infected-sus-std>1%
  infected-sus-fungi>1%
 
  initial-inf-patches 
  initial-inf-patches-0        ; wild type
  initial-inf-patches-1        ; virulent strain
  
  mean-fungicide-appl
  year-first-survival
  time-90%inf-1
  survival-counter
  established
  establishment-risk
  min-day-res-breakdown
    
  blight-day                  ;weather variables
  blight-days-list                          
  blight-days-81 blight-days-82 blight-days-83 blight-days-84 blight-days-85 blight-days-86 blight-days-87 blight-days-88 blight-days-89 blight-days-90
  blight-days-91 blight-days-92 blight-days-93 blight-days-94 blight-days-95 blight-days-96 blight-days-97 blight-days-98 blight-days-99 blight-days-00
  blight-days-01 blight-days-02 blight-days-03 blight-days-04 blight-days-05 blight-days-06 blight-days-07 blight-days-08 blight-days-09 blight-days-10
  blight-days-11 blight-days-12 blight-days-13 blight-days-14 blight-days-15 blight-days-16
  temp                                
  temp-list
  temp-81 temp-82 temp-83 temp-84 temp-85 temp-86 temp-87 temp-88 temp-89 temp-90 temp-91 temp-92 temp-93 temp-94 temp-95 temp-96 temp-97 temp-98 temp-99 
  temp-00 temp-01 temp-02 temp-03 temp-04 temp-05 temp-06 temp-07 temp-08 temp-09 temp-10 temp-11 temp-12 temp-13 temp-14 temp-15 temp-16
  rad                                 
  rad-list
  rad-81 rad-82 rad-83 rad-84 rad-85 rad-86 rad-87 rad-88 rad-89 rad-90 rad-91 rad-92 rad-93 rad-94 rad-95 rad-96 rad-97 rad-98 rad-99
  rad-00 rad-01 rad-02 rad-03 rad-04 rad-05 rad-06 rad-07 rad-08 rad-09 rad-10 rad-11 rad-12 rad-13 rad-14 rad-15 rad-16 
]

;;;;;;;;;;;;;;;;;;;;;;;;
;;  SETUP PROCEDURES  ;;
;;;;;;;;;;;;;;;;;;;;;;;;

to load-map       
  clear-all                  ;settings 132 x 128 cells
  random_seed
  initialise-parameters
  load-landscape
  remove-nan-values
  color-patches
  setup-farmers
  set-field-data
  setup
  reset-ticks
end  


to random_seed               
  if not keep-seed?                                                    
  [                                                                   
    set seed-for-random new-seed                                    
  ]
  random-seed seed-for-random
end     

to initialise-parameters
  
  ;Time & space
  set start-year 1                 ; April 1                   
  set day-counter start-year
  set day 1
  set month "April"
  set end-year 183                 ; September 30
  set first-year 1
  set year-counter 1 
  set patchsize 40000              ; 200 x 200 m2
  set color-sus-cv yellow
  set color-res-cv green
  set color-non-potato brown
  
  ;Crop parameters
  set alfa 0.6
  set DMC 25
  set lec 0.7
  set temp-sum-maxlai 1000
  set temp-sum-tub-init 350

  ;Disease parameters
  set beta 20
  set cx200   0.11544             
  set cx400   0.01918          
  set cx600   0.00691          
  set cx800   0.00277         
  set cx1000  0.00125
  set tot-dispersed-spores 0.34393

  set eff-fungicides-max 1
  set eff-fungicides-min 0.01
  set inf-efficiency-res 0    
  set c-karman 0.35

  set application-interval 8        ; weekly interval 
  set t50 9
  set dep-vel 0.0255   
  set day-first-application (crop-emergence-avg - 1)  ;
  set burn-level 5
  
; MOVED TO INTERFACE: Baseline values
;  set lai-initial 0.05  
;  set max-lai-susceptible 5
;  set max-lai-resistant 5 
;  set LUE-sus 0.0010   
;  set LUE-res 0.0008 
;  set rd-lai 0.010
;  set rg-lai 0.015
;  set crop-emergence-avg 31        ; May 1
;  set harvest-date 183             ; September 30
;  set wind-speed_ 3
;  set frac-initial-infected 0.02  
;  set initial-inf-surface-area 0.01
;  set mutfrac 1.0E-7
;  set lesion-size 1E-4
;  set si 4.6E08 
;  set spore-survival 0.2  
;  set cur-eff 0.1  
;  set dep-eff 0.1   
;  set rg-lesions 0.1   
;  set inf-efficiency-std 0.03 

end
 
to load-landscape
  set potato-landscape gis:load-dataset "potato200.asc"
  set field-landscape gis:load-dataset "objectid200.asc"
  
  gis:set-world-envelope (gis:envelope-union-of (gis:envelope-of potato-landscape)
                                                (gis:envelope-of field-landscape)
                                                )  
  gis:apply-raster potato-landscape potato?
  gis:apply-raster field-landscape field-nr
end

to remove-nan-values
  ; note the use of the "<= 0 or >= 0" technique to filter out "not a number" values
  ask patches [
    if not ((potato? <= 0) or (potato? >= 0)) [
      set potato? false
    ]
    if potato? = 1 [
      set potato? true]
    if potato? = 0 [
      set potato? false]
    if not ((field-nr <= 0) or (field-nr >= 0)) [
      set field-nr 0]
    if (potato? and field-nr = 0) [
      set potato? false]  
  ]
end        

to color-patches 
  ask patches [
    set pcolor field-nr
    if potato? = false [
      set pcolor color-non-potato
    ]
    if field-nr = 0 [
      set pcolor black
    ]
  ]
end

to setup-farmers
  set-default-shape farmers "person" 
  ask patches [
    if potato? = true [
      sprout-farmers 1 [
        set field-id field-nr
        set size 1
      ]
    ]
  ]
  ask farmers [
    ask other farmers with [field-id = [field-id] of myself] [
      die
    ]
  ]
end

to set-field-data
  set potato-patches patches with [potato?]
  ask farmers [
    set field (patch-set patches with [potato? and field-nr = [field-id] of myself])
    set field-size count field
    hide-turtle
  ]  
end

to setup
  locate-cultivars
  select-spraying-fields
  copy-field-data
  calculate-landscape-parameters  
  load-cultivar-variables
  set-blight-day-lists
  set-temp-lists
  set-rad-lists
end

to locate-cultivars
  ;select the potato field with a resistant variety
  while [count farmers with [cultivar-field = 2] < (frac-res-fields_ * count farmers ) ] [
    ask one-of farmers [
      set cultivar-field 2]
    ]  
  ask farmers with [cultivar-field = 0 ] [
    set cultivar-field 1
  ]
end

to select-spraying-fields
  ; selection of the susceptible fields with fungicide application
  ask farmers [
    set spraying? false
  ]
  while [count farmers with [cultivar-field = 1 and spraying?] < ( frac-sus-fungicides_ * count farmers with [cultivar-field = 1] ) ] [
    ask one-of farmers with [cultivar-field = 1 ]  [
      set spraying? true
      set color red]
   ]
  ; selection of the resistant fields with fungicide application
  while [count farmers with [cultivar-field = 2 and spraying?] < ( frac-res-fungicides_ * count farmers with [cultivar-field = 2] ) ] [
    ask one-of farmers with [cultivar-field = 2 ]  [
      set spraying? true
      set color red]
   ]
  ask farmers [
    if not spraying? [
      set color blue
    ]
  ]
end

to copy-field-data
  ask farmers [
    ask field [
      set cultivar [cultivar-field] of myself
      set fungicides? [spraying?] of myself
    ] 
  ]    
end

to calculate-landscape-parameters  
  set sus-patches patches with [cultivar = 1]
  set res-patches patches with [cultivar = 2] 
  set nr-potato-patches count potato-patches
  set nr-sus-patches count sus-patches
  set nr-res-patches count res-patches
  set nr-sus-std-patches count patches with [cultivar = 1 and not fungicides?]
  set nr-sus-fungi-patches count patches with [cultivar = 1 and fungicides?]
end

to load-cultivar-variables  
  ask patches [
    set spores-dispersed-0 []
    set spores-dispersed-1 [] 
  ]
  ask sus-patches
   [ 
    set max-lai max-lai-susceptible
    set inf-efficiency-0 inf-efficiency-std     
    set inf-efficiency-1 inf-efficiency-std     
    set LUE LUE-sus
   ]
  ask res-patches 
   [
    set max-lai max-lai-resistant
    set inf-efficiency-0 inf-efficiency-res 
    set inf-efficiency-1 inf-efficiency-std     
    set LUE LUE-res
   ] 
  ask potato-patches [
    set end-tub harvest-date 
    ifelse fungicides? [
      set eff-fungicides eff-fungicides-min
      ]       
    [                 
      set eff-fungicides eff-fungicides-max
      ]   
  ]   
end

;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;  MAIN PROCEDURE  ;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;


to go
  start-new-year
  update-growing-potatoes
  select-blight-day
  select-temp
  calculate-growing-degree-days
  calculate-sum-temp
  select-radiation                      
  calculate-growth-parameters
  apply-fungicides          
  calculate-rates
  spore-growth               
  update-states
  destroy-haulm
;  calculate-mean-variables                ; turn process on to update model output every time step
  end-season
  save-in-file   
  set day-counter day-counter + 1
  set day day + 1
  tick 
  select-date  
  if (year-counter > 36) [
    write "end simulation"
    stop
  ]    
end

to start-new-year
  if day-counter = start-year              
  [  
    reset-variables
    load-cultivar-variables-yearly
    load-year-data
    start-infection
  ]
end

to reset-variables
  set blight-day-counter 0
  ask patches 
  [
    set infection-level-0 0
    set infection-level-1 0
    set infection-level-total 0
    set initial-day-0 0
    set initial-day-1 0
    set spore-production-0 0
    set spore-production-1 0
    set virulent-spores-1 0
    set total-spores-0 0
    set total-spores-1 0
    set yield 0
    set sum-temp 0
    set broken-resistance? false 
    set fungicide-appl 0
    set growth-period 0
    set lai-rate 0
    set yield-rate 0
    set inf-rate-0 0
    set inf-rate-1 0
    
    set in-inf? false
    set infected-0? false
    set l0-0 0
    set l1-0 0
    set l2-0 0
    set l3-0 0
    set l4-0 0
    set l5-0 0
    set inf-0 0
    set nlinf-0 0
    set infected-1? false
    set l0-1 0
    set l1-1 0
    set l2-1 0
    set l3-1 0 
    set l4-1 0
    set l5-1 0
    set inf-1 0
    set nlinf-1 0
  ]
end

to load-cultivar-variables-yearly
  ask sus-patches 
   [ 
    set pcolor color-sus-cv
    set crop-emergence crop-emergence-avg 
    set lai lai-initial
   ]
  ask res-patches
   [
    set pcolor color-res-cv
    set crop-emergence crop-emergence-avg
    set lai lai-initial
   ] 
  ask potato-patches [
    set rgr rg-lesions
    if fungicides? [
      set application-day day-first-application  ; day of first application
      set eff-fungicides eff-fungicides-max      ; after first application changed in 'fungicide-application' procedure
    ]
  ]
end

to load-year-data
    if year-counter = 1 [
      set blight-days-list blight-days-81  ;93
      set temp-list temp-81
      set rad-list rad-81
      ] 
    if year-counter = 2 [
      set blight-days-list blight-days-82  ;91
      set temp-list temp-82
      set rad-list rad-82   
      ]
    if year-counter = 3 [
      set blight-days-list blight-days-83
      set temp-list temp-83
      set rad-list rad-83  
      ]
    if year-counter = 4 [
      set blight-days-list blight-days-84
      set temp-list temp-84
      set rad-list rad-84
      ]
    if year-counter = 5 [
      set blight-days-list blight-days-85
      set temp-list temp-85
      set rad-list rad-85     
      ]
    if year-counter = 6 [
      set blight-days-list blight-days-86
      set temp-list temp-86
      set rad-list rad-86
      ]
    if year-counter = 7 [
      set blight-days-list blight-days-87
      set temp-list temp-87
      set rad-list rad-87  
      ]
    if year-counter = 8 [
      set blight-days-list blight-days-88
      set temp-list temp-88
      set rad-list rad-88  
      ]
    if year-counter = 9 [
      set blight-days-list blight-days-89
      set temp-list temp-89
      set rad-list rad-89  
      ]
    if year-counter = 10 [
      set blight-days-list blight-days-90
      set temp-list temp-90
      set rad-list rad-90
      ]
    if year-counter = 11 [
      set blight-days-list blight-days-91
      set temp-list temp-91
      set rad-list rad-91
      ]
    if year-counter = 12 [
      set blight-days-list blight-days-92
      set temp-list temp-92
      set rad-list rad-92
      ]
    if year-counter = 13 [
      set blight-days-list blight-days-93
      set temp-list temp-93
      set rad-list rad-93
      ]
    if year-counter = 14 [
      set blight-days-list blight-days-94
      set temp-list temp-94
      set rad-list rad-94
      ] 
    if year-counter = 15 [
      set blight-days-list blight-days-95
      set temp-list temp-95
      set rad-list rad-95
      ] 
    if year-counter = 16 [
      set blight-days-list blight-days-96
      set temp-list temp-96
      set rad-list rad-96
      ]
    if year-counter = 17 [
      set blight-days-list blight-days-97
      set temp-list temp-97
      set rad-list rad-97
      ]
    if year-counter = 18 [
      set blight-days-list blight-days-98
      set temp-list temp-98
      set rad-list rad-98
      ]
    if year-counter = 19 [
      set blight-days-list blight-days-99
      set temp-list temp-99
      set rad-list rad-99
      ]
    if year-counter = 20 [
      set blight-days-list blight-days-00
      set temp-list temp-00
      set rad-list rad-00
      ]
    if year-counter = 21 [
      set blight-days-list blight-days-01
      set temp-list temp-01
      set rad-list rad-01
      ]
    if year-counter = 22 [
      set blight-days-list blight-days-02
      set temp-list temp-02
      set rad-list rad-02
      ]
    if year-counter = 23 [
      set blight-days-list blight-days-03
      set temp-list temp-03
      set rad-list rad-03
      ]
    if year-counter = 24 [
      set blight-days-list blight-days-04
      set temp-list temp-04
      set rad-list rad-04
      ]
    if year-counter = 25 [
      set blight-days-list blight-days-05
      set temp-list temp-05
      set rad-list rad-05
      ]
    if year-counter = 26 [
      set blight-days-list blight-days-06
      set temp-list temp-06
      set rad-list rad-06
      ]
    if year-counter = 27 [
      set blight-days-list blight-days-07
      set temp-list temp-07
      set rad-list rad-07
      ]
    if year-counter = 28 [
      set blight-days-list blight-days-08
      set temp-list temp-08
      set rad-list rad-08
      ]
    if year-counter = 29 [
      set blight-days-list blight-days-09
      set temp-list temp-09
      set rad-list rad-09
      ]
    if year-counter = 30 [
      set blight-days-list blight-days-10
      set temp-list temp-10
      set rad-list rad-10
      ]
    if year-counter = 31 [
      set blight-days-list blight-days-11
      set temp-list temp-11
      set rad-list rad-11
      ]
    if year-counter = 32 [
      set blight-days-list blight-days-12
      set temp-list temp-12
      set rad-list rad-12
      ]
    if year-counter = 33 [
      set blight-days-list blight-days-13
      set temp-list temp-13
      set rad-list rad-13
      ]
    if year-counter = 34 [
      set blight-days-list blight-days-14
      set temp-list temp-14
      set rad-list rad-14
      ]
    if year-counter = 35 [
      set blight-days-list blight-days-15
      set temp-list temp-15
      set rad-list rad-15
      ]
    if year-counter = 36 [
      set blight-days-list blight-days-16
      set temp-list temp-16
      set rad-list rad-16
      ]                   
end


to start-infection
  if infected-0-sum = 0 [           ; at the start of the simulation all initial infections belong to the wild type
    set infected-0-sum 1]
  if carry-over? = false [
    winter-survival-false]
  if carry-over? = true [
    winter-survival-true]
end

to winter-survival-false  
  let new-infected-patches-tot round (frac-initial-infected * nr-potato-patches * 4 )
 
  while [ count patches with [ in-inf?] < new-infected-patches-tot ] 
    [ask one-of potato-patches with [not in-inf?] [
        ifelse cultivar = 1 [
          set in-inf? true
          set infected-0? true
          set l1-0 initial-inf-surface-area
          set pcolor orange
          set initial-day-0 crop-emergence]
        [set in-inf? true]     
    ]
  ]
    
; To analyse establishment risk
  if year-counter > first-year [                                
    let nr-inf-1-infections round (infected-1-sum / (infected-0-sum + infected-1-sum) * new-infected-patches-tot)      
    ifelse nr-inf-1-infections > 0 [
      set established 1 
      set survival-counter (survival-counter + 1)    
      ]
    [
      set established 0    
    ]
  ]
  set initial-inf-patches (count patches with [ infected-0? or infected-1? ] ) 
  set initial-inf-patches-0 (count patches with [ infected-0? ] )
  set initial-inf-patches-1 (count patches with [ infected-1? ] ) 
end   

to winter-survival-true
  let new-infected-patches-tot round (frac-initial-infected * nr-potato-patches * 4 ) 
  if year-counter = first-year [
  while [ count patches with [ in-inf?] < new-infected-patches-tot ] 
    [ask one-of potato-patches with [not in-inf?] [
        ifelse cultivar = 1 [
          set in-inf? true
          set infected-0? true
          set l1-0 initial-inf-surface-area
          set pcolor orange
          set initial-day-0 crop-emergence]
        [set in-inf? true]     
    ]
  ]
  ]    
  if year-counter > first-year [     
    let nr-inf-0-infections round (infected-0-sum / (infected-0-sum + infected-1-sum) * new-infected-patches-tot)                         
    let nr-inf-1-infections round (infected-1-sum / (infected-0-sum + infected-1-sum) * new-infected-patches-tot)                                       
    if nr-inf-0-infections > 0 [
       while [ count patches with [ in-inf?] < nr-inf-0-infections ] 
        [ask one-of potato-patches with [not in-inf?] [
          ifelse cultivar = 1 [
            set in-inf? true
            set infected-0? true
            set l1-0 initial-inf-surface-area
            set pcolor orange
            set initial-day-0 crop-emergence]
          [set in-inf? true]     
    ]
  ]
  ]      
    if nr-inf-1-infections > 0 [  
    while [ count patches with [ infected-1? ] < nr-inf-1-infections ] 
      [ask one-of potato-patches with [not infected-1?]  [
          set infected-1? true
          set l1-1 initial-inf-surface-area        
          set pcolor magenta
          set initial-day-1 crop-emergence
      ]
    ]
    ]
  ]

  set initial-inf-patches (count patches with [ infected-0? or infected-1? ] ) 
  set initial-inf-patches-0 (count patches with [ infected-0? ] )
  set initial-inf-patches-1 (count patches with [ infected-1? ] ) 
  if initial-inf-patches-1 > 0 and year-first-survival = 0 [
    set year-first-survival year-counter 
  ] 
  if (initial-inf-patches-1 > (0.9 * initial-inf-patches) and time-90%inf-1 = 0) [
    set time-90%inf-1 (year-counter - year-first-survival)] 
end

to update-growing-potatoes
  set growing-potatoes patches with [potato? and day-counter >= crop-emergence and day-counter <= end-tub and infection-level-total < 100]
end

to select-blight-day
    set blight-day first blight-days-list
    set blight-days-list remove-item 0 blight-days-list

  if day-counter >= crop-emergence-avg [
    set blight-day-counter (blight-day-counter + blight-day) 
  ]
end

to select-temp
  set temp first temp-list
  set temp-list remove-item 0 temp-list
end  

to calculate-growing-degree-days
  set growing-degrees (temp - 2)
end

to calculate-sum-temp
  ask growing-potatoes [
    set sum-temp (sum-temp + growing-degrees)
  ]
end
  
to select-radiation
  set rad first rad-list
  set rad-list remove-item 0 rad-list
end

to calculate-growth-parameters
  ask potato-patches [    
    set tuber-growth-rate ( rad * LUE * 100 / DMC )        
  ]
   
end

to apply-fungicides  
  ask growing-potatoes with [fungicides? and day-counter > application-day] [
    if fungicide-appl = 0 [
      set fungicide-appl (fungicide-appl + 1)
    ]
    if (day-counter - application-day = application-interval ) [  ; = 8 instead of 7 to prevent dividing by 0
      set application-day (day-counter - 1)   ;  day-counter - 1 to prevent dividing by 0
      set fungicide-appl (fungicide-appl + 1)
    ]
    
    set eff-fungicides (eff-fungicides-min + ((eff-fungicides-max - eff-fungicides-min) / (1 + ((t50 / (day-counter - application-day)) ^ beta ))))
  ]  
  ask growing-potatoes with [fungicides? and infection-level-total > 1] [
    set rgr (cur-eff * rg-lesions)  
  ]   
end 

to calculate-rates
  ask growing-potatoes 
  [
    ifelse (sum-temp < temp-sum-maxlai )     ; when temp-sum reaches 1000 degrees, leaves will start to decrease
      [
        set lai-rate (rg-lai * growing-degrees * lai * (1 - (lai / max-lai) ^ alfa)) 
      ]
      [ set lai-rate (- rd-lai * growing-degrees * lai * (1 - (lai / max-lai)))
      ]      
    if sum-temp > temp-sum-tub-init [    ; weather data influences the moment of tuber initialisation (based on sum-temp)
      set yield-rate (tuber-growth-rate * (1 - (2 * infection-level-total / 100)) * (1 - exp(-1 * lec * lai)) * 10000 )          
    ]
    set inf-rate-0 nlinf-0 * rgr
    set inf-rate-1 nlinf-1 * rgr
  
  ]           
end

to spore-growth
  if (blight-day = 1) [
    ; reset variables
    ask patches [
      set spore-production-0 0
      set spore-production-1 0
      set virulent-spores-1 0  
      set spores-dispersed-0 []
      set spores-dispersed-1 []    
    ]    
    spore-production
    escape-fraction
    spore-dispersal
    new-infections    
  ]
end                         

to spore-production
  ask growing-potatoes [
    if inf-0 > 0 [
      set spore-production-0 (inf-0 * si )
      set virulent-spores-1 (spore-production-0 * mutfrac)
      set spore-production-0 (spore-production-0 - virulent-spores-1)
    ]
    if inf-1 > 0 [
      set spore-production-1 (inf-1 * si )
    ]
    set spore-production-1 (spore-production-1 + virulent-spores-1)
  ]    
end

to escape-fraction
  ask growing-potatoes [ 
    set escape-frac exp (- lai * sqrt( (dep-vel * (lai + 1) ) / (c-karman * wind-speed_) ) )
   ]  
end

to spore-dispersal  
  set wind-direction one-of [1 2 3 4]
      
  if wind-direction = 1 [
        
    ; PATCHES THAT PRODUCE WILDTYPE-SPORES
    ask patches with [spore-production-0 > 0] [
      let my-spore-production-0 (spore-production-0 * escape-frac)
          
      ask (patch-set patch-at 0 -1 patch-at -1 -1) [
        set spores-dispersed-0 lput (cx200 * my-spore-production-0) spores-dispersed-0]      

      ask (patch-set patch-at 0 -2 patch-at -1 -2 patch-at -2 -1) [
        set spores-dispersed-0 lput (cx400 * my-spore-production-0) spores-dispersed-0]
         
      ask (patch-set patch-at 0 -3 patch-at -1 -3 patch-at -2 -2 patch-at -3 -1 ) [
        set spores-dispersed-0 lput (cx600 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at 0 -4 patch-at -1 -4 patch-at -2 -3 patch-at -3 -3 patch-at -3 -2 patch-at -4 -1) [
        set spores-dispersed-0 lput (cx800 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at 0 -5 patch-at -1 -5 patch-at -2 -5 patch-at -2 -4 patch-at -3 -4 patch-at -4 -3 patch-at -4 -2 patch-at -5 -2 patch-at -5 -1) [
        set spores-dispersed-0 lput (cx1000 * my-spore-production-0) spores-dispersed-0]       
   ]       
   ; PATCHES THAT PRODUCE VIRULENT SPORES
   ask patches with [spore-production-1 > 0] [
      let my-spore-production-1 (spore-production-1 * escape-frac)
          
      ask (patch-set patch-at 0 -1 patch-at -1 -1) [
        set spores-dispersed-1 lput (cx200 * my-spore-production-1) spores-dispersed-1]      

      ask (patch-set patch-at 0 -2 patch-at -1 -2 patch-at -2 -1) [
        set spores-dispersed-1 lput (cx400 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at 0 -3 patch-at -1 -3 patch-at -2 -2 patch-at -3 -1 ) [
        set spores-dispersed-1 lput (cx600 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at 0 -4 patch-at -1 -4 patch-at -2 -3 patch-at -3 -3 patch-at -3 -2 patch-at -4 -1) [
        set spores-dispersed-1 lput (cx800 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at 0 -5 patch-at -1 -5 patch-at -2 -5 patch-at -2 -4 patch-at -3 -4 patch-at -4 -3 patch-at -4 -2 patch-at -5 -2 patch-at -5 -1) [
        set spores-dispersed-1 lput (cx1000 * my-spore-production-1) spores-dispersed-1]
   ]
  ]        

  if wind-direction = 2 [       
    ; PATCHES THAT PRODUCE WILDTYPE-SPORES
    ask patches with [spore-production-0 > 0] [
      let my-spore-production-0 (spore-production-0 * escape-frac)
          
      ask (patch-set patch-at -1 0 patch-at -1 1) [
        set spores-dispersed-0 lput (cx200 * my-spore-production-0) spores-dispersed-0]      

      ask (patch-set patch-at -2 0 patch-at -2 1 patch-at -1 2) [
        set spores-dispersed-0 lput (cx400 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at -3 0 patch-at -3 1 patch-at -2 2 patch-at -1 3) [
        set spores-dispersed-0 lput (cx600 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at -4 0 patch-at -4 1 patch-at -3 2 patch-at -3 3 patch-at -2 3 patch-at -1 4)[
        set spores-dispersed-0 lput (cx800 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at -5 0 patch-at -5 1 patch-at -5 2 patch-at -4 2 patch-at -4 3 patch-at -3 4 patch-at -2 4 patch-at -2 5 patch-at -1 5) [
        set spores-dispersed-0 lput (cx1000 * my-spore-production-0) spores-dispersed-0]

   ]        
    ; PATCHES THAT PRODUCE VIRULENT SPORES
    ask patches with [spore-production-1 > 0] [
      let my-spore-production-1 (spore-production-1 * escape-frac)
          
      ask (patch-set patch-at -1 0 patch-at -1 1) [
        set spores-dispersed-1 lput (cx200 * my-spore-production-1) spores-dispersed-1]      

      ask (patch-set patch-at -2 0 patch-at -2 1 patch-at -1 2) [
        set spores-dispersed-1 lput (cx400 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at -3 0 patch-at -3 1 patch-at -2 2 patch-at -1 3) [
        set spores-dispersed-1 lput (cx600 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at -4 0 patch-at -4 1 patch-at -3 2 patch-at -3 3 patch-at -2 3 patch-at -1 4) [
        set spores-dispersed-1 lput (cx800 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at -5 0 patch-at -5 1 patch-at -5 2 patch-at -4 2 patch-at -4 3 patch-at -3 4 patch-at -2 4 patch-at -2 5 patch-at -1 5) [
        set spores-dispersed-1 lput (cx1000 * my-spore-production-1) spores-dispersed-1]

    ] 
  ]
      
  if wind-direction = 3 [        
    ; PATCHES THAT PRODUCE WILDTYPE-SPORES
    ask patches with [spore-production-0 > 0] [
      let my-spore-production-0 (spore-production-0 * escape-frac)
          
      ask (patch-set patch-at 0 1 patch-at 1 1) [
        set spores-dispersed-0 lput (cx200 * my-spore-production-0) spores-dispersed-0]      

      ask (patch-set patch-at 0 2 patch-at 1 2 patch-at 2 1 ) [
        set spores-dispersed-0 lput (cx400 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at 0 3 patch-at 1 3 patch-at 2 2 patch-at 3 1 ) [
        set spores-dispersed-0 lput (cx600 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at 0 4 patch-at 1 4 patch-at 2 3 patch-at 3 3 patch-at 3 2 patch-at 4 1) [
        set spores-dispersed-0 lput (cx800 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at 0 5 patch-at 1 5 patch-at 2 5 patch-at 2 4 patch-at 3 4 patch-at 4 3 patch-at 4 2 patch-at 5 2 patch-at 5 1 ) [
        set spores-dispersed-0 lput (cx1000 * my-spore-production-0) spores-dispersed-0]

    ]        
    ; PATCHES THAT PRODUCE VIRULENT SPORES
    ask patches with [spore-production-1 > 0] [
      let my-spore-production-1 (spore-production-1 * escape-frac)
          
      ask (patch-set patch-at 0 1 patch-at 1 1) [
        set spores-dispersed-1 lput (cx200 * my-spore-production-1) spores-dispersed-1]      

      ask (patch-set patch-at 0 2 patch-at 1 2 patch-at 2 1 ) [
        set spores-dispersed-1 lput (cx400 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at 0 3 patch-at 1 3 patch-at 2 2 patch-at 3 1 ) [
        set spores-dispersed-1 lput (cx600 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at 0 4 patch-at 1 4 patch-at 2 3 patch-at 3 3 patch-at 3 2 patch-at 4 1) [
        set spores-dispersed-1 lput (cx800 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at 0 5 patch-at 1 5 patch-at 2 5 patch-at 2 4 patch-at 3 4 patch-at 4 3 patch-at 4 2 patch-at 5 2 patch-at 5 1 ) [
        set spores-dispersed-1 lput (cx1000 * my-spore-production-1) spores-dispersed-1]    
    ]
  ]
      
  if wind-direction = 4 [        
    ; PATCHES THAT PRODUCE WILDTYPE-SPORES
    ask patches with [spore-production-0 > 0] [
      let my-spore-production-0 (spore-production-0 * escape-frac)
          
      ask (patch-set patch-at 1 0 patch-at 1 -1) [
        set spores-dispersed-0 lput (cx200 * my-spore-production-0) spores-dispersed-0]      

      ask (patch-set patch-at 2 0 patch-at 2 -1 patch-at 1 -2) [
        set spores-dispersed-0 lput (cx400 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at 3 0 patch-at 3 -1 patch-at 2 -2 patch-at 1 -3) [
        set spores-dispersed-0 lput (cx600 * my-spore-production-0) spores-dispersed-0]
       
      ask (patch-set patch-at 4 0 patch-at 4 -1 patch-at 3 -2 patch-at 3 -3 patch-at 2 -3 patch-at 1 -4) [
        set spores-dispersed-0 lput (cx800 * my-spore-production-0) spores-dispersed-0]
          
      ask (patch-set patch-at 5 0 patch-at 5 -1 patch-at 5 -2 patch-at 4 -2 patch-at 4 -3 patch-at 3 -4 patch-at 2 -4 patch-at 2 -5 patch-at 1 -5) [
        set spores-dispersed-0 lput (cx1000 * my-spore-production-0) spores-dispersed-0]
    ]
    ; PATCHES THAT PRODUCE VIRULENT SPORES              
    ask patches with [spore-production-1 > 0] [
      let my-spore-production-1 (spore-production-1 * escape-frac)
          
      ask (patch-set patch-at 1 0 patch-at 1 -1) [
        set spores-dispersed-1 lput (cx200 * my-spore-production-1) spores-dispersed-1]      

      ask (patch-set patch-at 2 0 patch-at 2 -1 patch-at 1 -2) [
        set spores-dispersed-1 lput (cx400 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at 3 0 patch-at 3 -1 patch-at 2 -2 patch-at 1 -3) [
        set spores-dispersed-1 lput (cx600 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at 4 0 patch-at 4 -1 patch-at 3 -2 patch-at 3 -3 patch-at 2 -3 patch-at 1 -4) [
        set spores-dispersed-1 lput (cx800 * my-spore-production-1) spores-dispersed-1]
          
      ask (patch-set patch-at 5 0 patch-at 5 -1 patch-at 5 -2 patch-at 4 -2 patch-at 4 -3 patch-at 3 -4 patch-at 2 -4 patch-at 2 -5 patch-at 1 -5) [
        set spores-dispersed-1 lput (cx1000 * my-spore-production-1) spores-dispersed-1]
    ]
  ]

 ;  After dispersal of the spores from different patches the dispersed spores are summed    
  ask patches [
    set total-spores-0 round ((sum spores-dispersed-0)  + spore-production-0 * (1 - tot-dispersed-spores * escape-frac ) )
    set total-spores-1 round ((sum spores-dispersed-1)  + spore-production-1 * (1 - tot-dispersed-spores * escape-frac ) )
  ]   
end
  
to new-infections 
  ask growing-potatoes [
    if         (total-spores-0 * inf-efficiency-0 * eff-fungicides * dep-eff * spore-survival >= 1 ) [
      set l0-0 (total-spores-0 * inf-efficiency-0 * eff-fungicides * dep-eff * spore-survival * lesion-size )
      if infected-0? = false [
        set infected-0? true
        set initial-day-0 day-counter
      ]
    ]       
    if         (total-spores-1 * inf-efficiency-1 * eff-fungicides * dep-eff * spore-survival >= 1 ) [
      set l0-1 (total-spores-1 * inf-efficiency-1 * eff-fungicides * dep-eff * spore-survival * lesion-size )
      if infected-1? = false [
        set infected-1? true
        set initial-day-1 day-counter
        if cultivar = 2 [
          set broken-resistance? true
        ]
      ]
    ]
  ]     
end 

to update-states
  ask growing-potatoes 
  [
    set lai lai + lai-rate
    set yield yield + yield-rate

    if (initial-day-0 > 0 and day-counter >= initial-day-0) [
      set nlinf-0 (nlinf-0 + inf-0)
      set inf-0 ( l5-0 + inf-rate-0)
      set l5-0 l4-0
      set l4-0 l3-0
      set l3-0 l2-0
      set l2-0 l1-0
      set l1-0 l0-0
      set l0-0 0
    ]
    if (initial-day-1 > 0 and day-counter > initial-day-1) [
      set nlinf-1 (nlinf-1 + inf-1)  
      set inf-1 ( l5-1 + inf-rate-1)
      set l5-1 l4-1
      set l4-1 l3-1
      set l3-1 l2-1
      set l2-1 l1-1       
      set l1-1 l0-1
      set l0-1 0
    ]
    set infection-level-0 ((nlinf-0 + inf-0 + l5-0 + l4-0 + l3-0 + l2-0 + l1-0) / (lai * patchsize)  * 100 )
    set infection-level-1 ((nlinf-1 + inf-1 + l5-1 + l4-1 + l3-1 + l2-1 + l1-1) / (lai * patchsize) * 100 )
    set infection-level-total infection-level-0 + infection-level-1 ;
  ]
end

to calculate-mean-variables
  
  set mean-yield (mean [yield] of potato-patches / 1000)       ;tonnes/ha
  set infected-tot>1% count patches with [infection-level-total > 1] / nr-potato-patches * 100
  
  if nr-sus-std-patches > 0 [
    set mean-yield-sus-std (mean [yield] of patches with [cultivar = 1 and not fungicides?] / 1000)]
  if nr-sus-fungi-patches > 0 [       
    set mean-yield-sus-fungi (mean [yield] of patches with [cultivar = 1 and fungicides?] / 1000)]
  if nr-res-patches > 0 [   
    set mean-yield-res (mean [yield] of res-patches / 1000)]   
  if count patches with [cultivar = 2] > 0 [
    set infected-res>0% (count patches with [cultivar = 2 and infected-1?] / nr-res-patches) * 100 
  ]
end


to destroy-haulm 
  ask growing-potatoes [
    if ( (infection-level-total) > burn-level ) [
      set pcolor red
      set infection-level-total 100 
      set growth-period (day-counter - crop-emergence)
    ]   
  ]
end

to end-season
  if day-counter = end-year [
    calculate-mean-variables
           
    set mean-fungicide-appl mean [fungicide-appl] of potato-patches           
    set infected-tot>5% count patches with [infection-level-total > 5] / nr-potato-patches * 100   
    
    set infected-0-sum sum [infection-level-0] of potato-patches 
    set infected-1-sum sum [infection-level-1] of potato-patches

    if nr-sus-std-patches > 0 [
      set infected-sus-std>1% count patches with [cultivar = 1 and not fungicides? and infection-level-total > 1] / nr-sus-std-patches * 100
    ]  
    if nr-sus-fungi-patches > 0 [
      set infected-sus-fungi>1% count patches with [cultivar = 1 and fungicides? and infection-level-total > 1] / nr-sus-fungi-patches * 100
    ]
    if nr-res-patches > 0 [
      set infected-res>1% (count patches with [cultivar = 2 and infection-level-total > 1 ] / nr-res-patches) * 100
      ifelse count patches with [broken-resistance?] > 0 [
        set min-day-res-breakdown min [initial-day-1] of res-patches with [broken-resistance?] ]  
      [set min-day-res-breakdown 0]
    ]
 if year-counter = 36 [
   set establishment-risk (survival-counter / 36 * 100)]
  ]
end

;;;;;;;;;;;;;;;;;;;;
;  REPORT RESULTS  ;
;;;;;;;;;;;;;;;;;;;; 

to save-in-file
  if day-counter = end-year [
   if file-exists? "Name-file.csv" [                   ; create a file to save model output
    file-open "Name-file.csv"
    file-type year-counter
    file-type ","
    file-type seed-for-random
    file-type ","
    file-type carry-over?
    file-type ","
    file-type frac-res-fields_
    file-type ","

    file-type mean-yield
    file-type ","  
    file-type mean-yield-sus-std
    file-type ","  
    file-type mean-yield-sus-fungi
    file-type ","
    file-type mean-yield-res
    file-type ","  
    file-type infected-tot>1%              
    file-type "," 
    file-type infected-res>0%                     
    file-type "," 
    file-type establishment-risk
    file-type "," 
    file-type time-90%inf-1
    file-type ","  
    file-type min-day-res-breakdown
    file-type "," 
    file-type infected-sus-std>1%
    file-type ","  
    file-type infected-sus-fungi>1%
    file-type ","
    file-type infected-res>1%     
    file-type ","
    file-type mean-fungicide-appl
    file-type "," 
    file-type year-first-survival  
    file-type ","   
    file-type established
    file-type ","  
    file-type initial-inf-patches
    file-type ","
    file-type initial-inf-patches-0
    file-type ","
    file-type initial-inf-patches-1
    file-type ","
    file-type infected-0-sum  
    file-type ","  
    file-type infected-1-sum  
    file-type ","  
    file-type infected-tot>5%              
    file-print ""
    file-close
   ]
  ]
end


to select-date 
    
  if (day-counter = 31 or day-counter = 62 or day-counter = 92 or day-counter = 123 or day-counter = 154 ) [
    set day 1]
  
  if (day-counter >= 1)  [
    set month "April"
  ]
  if (day-counter >= 31) [      
    set month "May"
  ]
  if (day-counter >= 62 )[      
    set month "June"
  ]
  if (day-counter >= 92 )[      
    set month "July"
  ]
  if (day-counter >= 123 )[      
    set month "August"
  ]
  if (day-counter >= 154 )[      
    set month "September"
  ]
  
  if day-counter = (end-year + 1) [
    set day 1
    set month "April"
    set day-counter start-year   
    set year-counter year-counter + 1     
  ]  

end 

to set-blight-day-lists

; DATA EELDE
  set blight-days-81 [1 1 1 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 1 0 0 0 1 1 1 1 1 0 0 1 0 0 0 1 0 0 
1 0 0 1 1 0 0 1 0 0 1 0 1 0 0 0 1 0 0 1 0 0 0 0 0 0 1 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0 1 0 1 1 1 1 1 0 1 1 1 
1 1 1 1 1 1 1 1 1 0 1 0 1 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 0 1 0 0 1 0 0 1 1 1 0 1 0 0 0 0 0 1 0 0 1 1 1 1 1 0 
1 1 1 1 0 1 1 1 0 0 1 0 1 0 0    
    ]
  set blight-days-82 [0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 1 1 1 1 1 1 1 0
 0 1 0 0 0 0 0 0 0 0 0 1 1 0 1 0 1 1 0 0 0 0 0 1 1 0 0 0 1 1 0 1 1 1 1 1 1 0 0 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 
0 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 1 1 1 1 0 0 1 0 1 1 1 1 1 1 1 1 0 0 1 1 1 0 0 1 0 1 0 1 1 0 0 0 0 1 
1 1 1 1 0 1 0 0 1 0 0 1 1 0 1
    ]
  set blight-days-83 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 0 1 1 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 1 0 0 1 1 1
 0 0 0 0 0 0 0 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 1 1 0 0 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0
 0 1 1 1 1 0 1 0 0 0 0 0 1 1 1
    ]
  set blight-days-84 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 1 0 1 1 1 1 1
 1 1 1 1 0 0 1 0 1 1 0 1 1 1 0 0 0 1 1 1 1 1 1 1 0 0 0 0 0 0 0 1 0 0 0 0 1 0 1 0 1 0 1 0 0 0 0 1 1 1 1 1 1 1 0 1
 0 0 0 1 1 1 1 1 1 0 0 1 0 0 1 1 1 0 1 1 1 1 1 1 1 1 0 0 0 1 0 0 0 0 0 0 1 1 0 1 0 1 1 0 0 0 0 1 0 1 1 1 1 0 1 1
 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1
    ]
  set blight-days-85 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 1 1 0 1 0 0 0 0 0 1 1 0 0 0
 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 1 0 0 0 0 0 0 1 1 1 0 1 0 1 1 1 1 1 1 1 1 0 0 0 0 0 1 1 1 1 0 0 0 0 0 1 0 1 1 0
 1 0 0 1 1 0 0 1 1 1 1 1 1 1 1 1 1 1 0 1 1 0 0 0 1 1 1 1 1 0 0 1 1 0 1 1 0 0 1 1 0 0 0 0 1 1 0 0 1 0 0 1 1 1 0 1
 1 1 0 1 1 1 1 1 1 1 1 1 1 0 1
    ]
  set blight-days-86 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 0 0 1 1 0 0 0 1 0 0 0 1 0 1 1 0 0 0 0 0 0 0 0 1 0 0 0 0 1
 1 1 1 1 1 0 1 0 0 0 0 0 0 0 1 0 0 0 1 1 0 0 0 1 0 0 0 0 1 1 1 1 1 0 0 1 1 1 1 1 1 1 1 1 0 0 1 0 0 0 0 0 0 0 1 0
 1 0 0 0 0 1 1 1 1 0 0 1 0 1 1
    ]  
  set blight-days-87 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 1 1 1 0 0 1 1 0 1 0 0 1 0 0 0 0 0 1 0 1 1 0 0 1 1 1 0 0 1 0 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 1
 0 0 0 1 0 1 0 1 1 1 0 1 1 0 0 0 0 1 1 1 0 1 1 1 1 1 1 1 1 0 1 0 0 0 1 1 1 1 0 1 0 0 1 1 1 1 1 1 1 1 1 1 0 1 1 1
 0 1 1 0 1 1 0 1 1 1 0 0 0 0 0
    ]  
  set blight-days-88 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 1 1 1 0 1 1 1 1 0 0 0 1 1 1 1 1 0 0 0 0 0 0 1 0 1 0 1 0 1 1 1 1 1 1 1 0 1 1 1 1 1 1 1 1 1 0 1 1 1 1 1 1 1 1 1 1
 1 1 0 0 0 1 1 0 0 0 1 1 0 1 1 0 1 1 1 0 0 0 0 0 0 1 0 1 0 0 1 1 1 1 1 1 1 0 1 1 0 1 1 1 1 0 1 0 1 0 1 1 0 1 1 1
 1 0 1 1 1 1 1 1 0 0 1 1 1 0 0
    ]  
  set blight-days-89 [0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 1 0 0 1 0 0 0 0 0 0 0 1 1
 0 0 0 1 0 0 1 0 0 1 1 0 0 0 0 1 0 1 1 0 1 0 1 0 0 0 0 1 0 0 1 1 1 1 0 0 1 0 0 1 1 1 1 0 1 0 1 1 1 0 0 0 0 0 1 0
 0 0 1 0 1 1 0 1 1 1 1 0 0 0 1
    ]
  set blight-days-90 [0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 1 0 1 1 0 0 1 1 0 1 1 1 0 1 0 0 1 0 0 1 1 0 0 1 0 1 0 0 1 0 1 0 0 0 0 1 1 1 0 0 1 0 0 0 1 0 1 1 0 0 0
 0 0 0 0 1 0 0 0 1 0 0 1 0 0 0 1 0 0 0 0 1 1 0 1 0 0 0 1 0 0 0 1 0 1 0 0 1 0 1 0 1 1 1 1 1 1 1 1 1 1 1 1 1 1 0 0
 0 0 0 1 0 1 0 0 1 1 0 0 0 1 1
    ]
  set blight-days-91 [1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 1 0 0 0 0 0 0 1 0 0 0 0 0 1 1 1 0 0 0 1
 1 1 0 0 1 0 0 1 0 0 0 1 1 0 0 1 1 1 1 1 1 0 0 1 1 0 0 1 1 1 1 0 1 0 1 1 1 0 0 0 0 0 0 0 1 0 0 0 0 1 0 1 1 0 1 1
 0 0 0 1 1 1 1 0 0 0 1 0 1 1 1 0 0 1 1 0 1 0 1 1 0 0 0 0 1 1 1 0 0 0 1 1 1 1 0 0 1 0 0 0 0 1 0 0 1 1 0 1 0 0 0 0
 1 0 1 1 0 0 0 0 1 1 1 1 1 1 1
    ]
  set blight-days-92 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 0 1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 1 0 0 0 0 0 0 0
 1 0 0 1 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 0 1 1 0 0 0 0 0 1 0 1 0 0 1 0 0 0 1 1 0 1 1 1 1 1 0 0 0 1 1 1 1 1 1 1
 0 0 0 1 1 1 0 0 0 0 0 1 1 1 0
    ]
  set blight-days-93 [0 0 1 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 1 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 1 0 1 0 1 1 1
 1 1 1 0 0 0 1 1 0 0 0 0 1 1 0 0 0 1 0 0 1 1 1 0 1 0 0 0 0 0 0 1 0 1 1 1 1 1 0 1 1 0 0 0 1 0 0 0 1 1 1 0 1 0 1 1
 1 1 1 0 1 1 0 1 1 1 1 1 0 1 1 1 1 1 1 0 0 0 1 0 1 0 1 0 0 1 1 1 1 0 0 1 0 0 0 0 0 0 1 1 1 0 0 0 0 1 1 1 0 0 1 1
 1 0 0 0 0 0 1 1 1 1 1 1 1 0 0
    ]

; DATA MARKNESSE

  set blight-days-94 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 1 1 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 1 1 1 0 0 1 0 0 1 0 1 0
 0 0 0 0 0 0 0 1 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 1 1 0 0 1 0 1 1 0 1 1 0 0 1 1 0 0 1 1 0 0 0 1 0 1 1
 0 0 1 1 1 0 0 0 0 1 1 1 0 0 0
 ]
  set blight-days-95 [1 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1
 0 0 0 0 1 0 0 1 1 1 0 1 0 1 1 1 1 0 1 1 1 1 1 0 1 1 0 0 0 0 1 1 0 0 1 0 0 1 0 0 0 1 1 0 0 0 0 0 0 0 0 0 1 0 0 0
 0 0 0 1 0 0 1 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 0 1 1 0 1 1 0 1 1 1 1
 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0
 ]
  set blight-days-96 [0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 1 1 0
 1 0 0 1 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 1 1 0 1 1 1 0 1 1 1 0 1 0 0 1 0 0 0 1 0 1 0 1 1 0 0 0 0 0 0
 0 0 0 0 0 1 0 0 1 0 1 1 0 0 0 0 1 1 1 0 0 0 1 0 0 0 1 1 0 0 0 1 1 0 1 0 1 1 1 1 1 0 0 1 1 1 0 0 0 1 0 0 1 0 1 1
 0 0 0 0 0 0 0 0 0 0 0 1 1 1 0
 ]
  set blight-days-97 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0
 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 0 1 1 0 0 0 0 0 0 0 0 1 0 1 1 1 1 1 1 1 0 1 1 0 1 0 0 1 0 0 0 0 0 0 0 1 0 0 0
 0 0 1 0 0 0 1 1 0 0 1 0 1 0 1 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 0 1 1 1 0 0 0 0 1 1 0 1 0 1 0 0 0 0 0 1 0 0
 0 0 1 1 0 0 0 0 1 0 1 0 1 1 1
 ]
  set blight-days-98 [0 1 1 0 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 1 0 0 1 1 1 0 0 0 1 1 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1
 0 1 1 1 1 0 0 0 1 0 1 1 0 0 0 1 1 0 0 1 1 0 0 1 1 0 0 1 1 0 0 0 1 0 1 0 0 0 0 1 0 0 0 1 1 1 1 0 0 1 1 1 1 0 0 0
 0 0 0 0 0 0 1 1 1 1 1 1 1 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 1 0 1 0 0 0 1 0 1 1 1 1 1 1 1 0 1 0 1 1 1 0 1
 1 0 0 1 1 1 1 1 1 1 1 1 1 1 1
 ]
  set blight-days-99 [0 0 0 1 1 1 1 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 0 0 1 1 0 1 0 0 0 0 0 0 1 0 0 0 0 0
 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 1 1 1 0 1 0 0 0 0 0 0 0 0 1 0 0 0
 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 1 1 0 1 0 0 1 0 0 0 1 0 1 0 0 0 0 0 0 0 0 1 1 1 1 0 1 0 0 0 0 1 0 0 1 0 0 0 0 1
 1 0 1 0 0 0 1 1 0 0 1 1 1 0 1
 ]
  set blight-days-00 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 1 0 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 1 0
 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 1 0 0 1 1 0 0 1 0 0 1 1 0 0 0 0
 0 1 1 1 1 1 0 1 1 1 0 0 0 1 1 1 0 1 0 0 0 1 1 0 0 1 1 0 0 0 1 1 1 0 1 0 0 1 1 1 1 1 1 0 0 0 0 1 1 1 1 1 0 1 1 1
 0 1 1 1 0 1 1 1 0 1 1 1 0 0 1
 ]
  set blight-days-01 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0
 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 0 0 0 0 0 1 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 1 1 1 0 0 1 1 1
 0 1 1 1 0 0 0 1 0 0 0 0 0 0 1 1 1 0 1 1 1 0 1 0 0 0 1 1 0 0 1 0 0 0 0 0 0 0 1 1 0 1 1 1 0 0 0 0 0 0 0 0 0 0 1 1
 0 0 1 1 1 1 0 1 1 1 1 1 0 1 1
 ]
  set blight-days-02 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 1 1 1 0 1 1 0 0 0 0 0 0 0 0 0 0 1 0 0 0
 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 1 1 1 1 0 0 0 0 1 1 1 0 0 1 1 0 0 0 0 0 0 1 1 1 1 1 1 1 0 1 1 1 1 0 0 0 0 0 0 0 1
 0 0 0 0 0 1 0 0 0 0 1 0 0 1 0 0 1 0 0 1 1 0 0 0 0 0 0 0 0 0 1 1 1 1 0 1 0 0 0 1 0 0 1 0 1 1 1 0 1 0 1 1 1 1 1 1
 1 0 0 1 1 1 1 1 0 1 1 1 1 1 0
 ]
  set blight-days-03 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1
 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 1 0 0 1 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 1 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 1 0 0 0 0 0 1 0 1 1 0 0 1 1 0 0 0
 1 1 0 0 1 0 0 0 0 0 0 1 0 1 0
 ]
  set blight-days-04 [0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 1 0 0 1 1
 1 0 1 0 1 1 1 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 1 0 0 0 0 0 1 1 1 0 0 0 1 1 0 1 0 0 1 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1
 ]
  set blight-days-05 [0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0
 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 1 1 1 0 0 0 0 1 0 0 0 0 0 0 0
 0 0 1 0 0 1 1 0 0 1 0 1 1 0 0 1 1 0 0 0 0 1 0 0 0 1 1 0 0 0 0 1 1 1 0 0 0 1 0 1 0 0 0 1 0 0 0 0 0 0 0 1 0 1 0 0
 1 0 0 0 0 0 0 0 0 1 1 0 1 0 1
 ]
  set blight-days-06 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 1 1 1 1 0 1 0 0 0 0 0 1 1 1 1 1 1 0 0 0 1 0 0 0 0 1 0 0 0 0 0 0 1 0 0 0
 0 0 0 0 1 0 0 0 0 0 0 1 1 0 0
 ]
  set blight-days-07 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 1 1 0 0 0 0
 1 1 1 0 0 1 0 1 1 0 1 0 0 0 1 0 0 0 1 1 0 1 1 1 0 0 1 1 1 1 1 0 0 0 1 0 0 0 1 1 0 0 0 0 0 1 0 0 0 0 0 0 0 1 0 0
 0 1 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 1 0 1 1 0 0 1 0 0 0 0 0 0 0 1 1 1 0 0 1 0 1 0 1 0 1 1 1 0
 0 1 1 0 1 1 1 1 1 1 1 1 1 1 1
 ]
  set blight-days-08 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 1 0 0 0 0 0 0 1 0 0 0
 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 0 1 0 0 0 1 0 1 0 0 0 0 0 1 0 0 0 1 0 0 0 0 1 1 0 1 0 1 0 0
 0 1 0 0 0 0 1 1 0 1 0 0 0 1 1
 ]
  set blight-days-09 [0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0
 0 1 0 0 0 0 0 0 0 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 1 0 1 0 0 0 0 0 0 0
 0 0 1 0 1 0 1 0 0 1 0 0 0 1 0 0 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 1 1 1 1 0
 1 0 0 1 1 0 1 0 1 0 0 0 1 0 1
 ]
  set blight-days-10 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 1 0 0 0 0 0 1 0 1 1 1 0 1 1 1 0 1 1 1 0 0 1 0 0 0 0 0 0 0 0 1 1 0 1 1 0 0 1 1 0 0 0 0 0 1 1 1 0 1 1 0
 0 0 0 0 0 1 1 1 1 0 1 1 1 0 1
 ] 
  set blight-days-11 [1 1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 1 0 0 1 0 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 1 1 0 0 0 0 0 0
 0 0 1 1 1 1 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 1 1 1 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 1 0 0 1 0 0 0 0 0 1 1 0 0 0 0 0
 0 1 0 0 0 0 0 1 0 0 0 1 1 1 1
 ] 
  set blight-days-12 [0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 1 0 1 0 0 0 0 0 1 1 0 0 0 1 1 0 0 0 1 0 0 0 0 1 0 0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 1 1 0 0 0 0
 0 0 0 0 0 0 0 1 0 1 1 0 1 0 1 0 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 1 0 0 1 1 1 0 0 1 1 0 0 0 0 0 0
 1 1 1 0 0 0 0 0 1 0 0 1 1 0 0
 ] 
  set blight-days-13 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 1 1 0 1 1 0 0 0 0 0
 0 0 0 1 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 1 1 0 0 0 0
 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 0 0 0 0 0 0 0 0 0 1 1 1 0 1 0 0 0 0 0 1 1 0 0 0 0 1 0 0 1 1 0 1 1 1 1 1 0
 0 0 0 0 1 1 1 1 1 1 0 0 0 0 0
 ] 
  set blight-days-14 [0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1 0 0 1 1 1 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0
 1 1 1 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 0 0 0 0 1
 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 1 1 1 1 1 0 0 0 1 0 0 0 1 1 1 1
 0 0 0 1 1 0 0 0 0 1 0 1 0 1 1
 ] 
  set blight-days-15 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0
 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 0 0 0 0 1 1 0 1 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0
 0 0 0 1 1 1 0 1 1 1 0 0 0 0 0
 ]   
  set blight-days-16 [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 1
 0 0 0 0 0 0 0 1 0 0 1 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0
 0 0 0 0 1 0 1 0 0 1 0 0 1 0 0 1 0 0 0 1 0 1 0 1 1 0 1 0 1 0 0 1 0 0 0 0 0 0 0 1 1 0 1 0 0 0 1 1 1 0 0 0 0 0 0 0
 0 1 0 0 0 0 0 1 0 0 1 0 0 0 0
 ] 

end



to set-temp-lists
  
; DATA EELDE  
  
  set temp-81 [11.75  8.94  8.87  6.75  6.39  6.25  8.65  8.18  9.83  10.99  14.23  15.03  10.15  7.23  7.84  7.81  5.35  5.10  6.08  5.60  5.10  4.55  1.92  2.60  6.28  8.84  8.75  5.04  6.85  9.14  6.40  5.36  3.88  5.85  7.15  6.82  13.05  15.29  16.68  19.33  20.58  18.62  17.62  13.17  12.04  14.20  11.61  12.59  15.25  17.63  21.54  16.93  13.10  13.20  11.88  11.52  12.23  11.53  13.49  15.36  18.25  18.75  19.94  17.13  15.70  14.37  14.14  15.05  15.90  16.75  14.61  12.45  13.86  10.50  16.40  16.02  13.17  11.42  10.53  10.39  10.40  11.69  13.75  14.31  15.99  15.78  12.68  13.12  13.35  12.20  11.61  13.92  14.38  15.81  14.29  15.54  17.40  16.85  19.45  22.67  21.10  17.65  16.80  15.78  15.05  15.40  15.03  14.64  12.33  13.76  15.20  15.65  14.39  15.81  13.73  13.57  14.68  15.48  15.98  16.16  14.44  13.43  16.01  12.95  15.53  18.80  20.81  21.72  21.32  20.28  18.71  17.32  16.86  14.18  17.18  19.89  20.03  16.86  13.41  14.66  15.87  14.18  13.37  14.35  13.65  13.38  14.70  16.64  13.66  15.43  14.62  13.64  12.48  13.77  13.65  13.08  13.06  14.07  14.26  16.20  17.90  17.75  16.37  17.78  16.60  14.02  11.86  13.52  15.50  15.33  16.28  14.87  15.22  14.85  14.01  13.63  12.62  13.70  13.53  15.43  12.28  11.90  11.73   
  ]
  set temp-82 [5.93  10.11  9.49  6.49  10.61  12.11  10.02  8.03  3.71  3.34  3.63  2.85  5.12  3.31  4.66  6.55  6.18  6.48  5.60  5.38  5.90  8.41  6.75  7.16  6.61  8.15  8.03  8.46  6.67  4.38  7.87  5.03  8.64  9.20  6.44  7.46  7.20  7.42  6.80  7.98  8.67  8.08  7.67  8.73  12.58  18.68  16.87  14.84  13.88  13.68  13.65  13.86  13.40  12.62  13.17  18.61  19.29  14.32  12.30  14.47  18.27  21.09  20.88  22.69  24.94  21.08  19.77  19.20  17.43  14.82  15.70  15.08  15.35  13.93  11.49  11.78  11.06  11.80  11.87  14.10  14.51  12.07  13.63  16.46  15.75  15.44  18.32  15.20  14.88  15.23  14.62  13.64  17.55  18.30  14.69  15.25  13.73  15.21  17.53  20.60  21.16  17.50  20.01  20.21  23.14  23.73  18.20  15.79  15.04  16.80  15.75  17.45  16.81  17.26  16.45  15.92  16.30  16.09  17.91  19.50  21.20  23.59  23.00  23.28  23.84  24.45  21.98  20.12  19.67  19.96  18.56  16.79  16.40  19.64  16.57  16.38  13.97  17.05  16.79  15.94  15.13  13.63  14.25  15.24  16.43  14.34  15.57  13.57  14.11  13.43  12.73  15.65  14.67  13.15  12.69  13.05  16.02  13.50  16.52  14.85  16.76  13.70  16.03  16.90  12.52  16.67  13.03  15.28  14.95  15.52  15.18  18.20  18.75  18.18  11.54  9.02  14.07  14.68  16.46  14.22  14.40  14.67  14.16
  ]
  set temp-83 [6.35  6.30  4.58  2.83  4.50  4.64  4.71  4.66  5.26  5.13  9.35  6.01  4.90  6.59  8.26  8.60  12.12  13.91  12.75  7.94  11.34  8.15  10.75  11.43  9.36  11.39  10.42  9.20  9.56  8.90  9.53  9.75  8.04  8.27  8.66  10.62  12.34  11.72  11.58  11.15  9.70  9.39  11.14  12.40  13.15  10.57  11.85  11.85  11.58  11.95  11.74  10.94  11.12  10.75  10.11  9.65  9.50  9.71  9.83  10.87  14.11  18.50  17.40  13.68  16.28  14.75  12.50  15.15  19.17  18.40  15.41  14.89  16.75  16.55  13.47  11.41  10.60  10.23  14.15  14.28  16.28  19.93  21.64  22.33  19.42  16.12  14.35  15.92  12.29  13.82  15.25  12.95  14.23  14.28  16.06  19.38  21.10  22.43  20.54  19.88  21.19  24.84  22.73  15.93  16.23  18.34  20.31  18.15  20.10  16.19  14.03  12.99  15.37  18.71  19.68  19.96  22.03  19.47  18.49  16.93  17.91  18.18  22.03  15.02  13.35  14.13  15.80  15.65  17.71  19.08  20.32  19.31  17.43  16.40  15.44  15.06  16.80  18.13  17.00  16.83  18.00  23.07  21.62  20.12  18.64  17.29  19.64  18.58  17.87  15.83  15.93  14.38  17.58  18.57  18.34  17.39  15.53  15.49  12.74  11.35  11.42  16.40  15.53  12.20  11.87  12.18  13.34  15.90  13.91  12.66  11.97  14.10  12.87  12.76  13.95  11.64  14.55  12.81  12.30  14.31  14.49  14.77  13.00
  ]
  set temp-84 [1.00  2.16  1.86  2.55  3.63  4.90  5.13  3.34  4.90  3.66  5.07  6.72  5.24  8.01  10.54  6.77  4.98  5.93  8.21  11.24  11.26  11.47  8.22  10.08  11.09  8.93  8.99  7.90  8.23  10.44  9.96  8.88  9.50  11.38  11.62  9.79  6.78  7.38  5.38  6.20  6.78  7.81  9.67  10.59  11.14  12.45  10.58  10.92  9.16  10.28  12.48  12.99  10.58  11.75  10.13  10.11  11.98  12.78  12.49  14.00  14.30  15.01  13.92  15.63  12.32  11.88  10.21  11.53  11.74  11.53  11.12  11.20  11.69  14.30  14.47  12.08  11.58  12.93  13.55  15.60  18.45  18.74  12.05  12.35  10.83  11.33  12.67  13.87  11.80  10.43  10.76  11.84  11.20  11.13  11.89  11.86  11.94  14.73  18.69  21.05  18.94  18.07  17.65  15.63  14.63  12.43  13.60  13.42  14.01  13.50  13.63  13.70  13.08  12.04  11.86  12.50  13.96  14.58  14.91  17.56  19.58  23.04  18.29  14.64  17.79  18.45  17.27  15.40  15.40  17.25  16.83  15.68  13.73  16.92  17.78  15.95  14.13  16.00  14.16  13.64  18.97  17.75  18.40  20.51  20.74  20.96  20.63  17.42  15.88  15.84  17.24  16.73  18.86  18.18  15.97  18.55  17.31  11.24  11.68  12.10  10.25  13.28  12.88  12.75  12.50  11.29  15.79  14.92  14.60  12.64  14.32  14.12  11.55  13.06  10.39  9.88  8.21  9.20  11.73  10.96  10.93  11.74  14.05
  ]
  set temp-85 [9.76  11.04  9.53  14.67  13.71  11.78  10.06  9.61  8.58  7.43  7.14  6.73  7.05  6.65  6.98  7.62  9.53  9.56  9.68  9.32  7.19  7.42  5.88  4.75  5.50  3.31  4.87  3.94  4.33  5.85  7.84  5.52  6.30  7.13  7.46  12.79  14.50  14.92  13.78  10.95  10.73  12.34  12.98  14.98  14.25  13.83  13.49  11.44  14.32  17.05  16.69  12.73  9.82  11.40  16.25  19.59  23.28  16.83  11.60  11.65  12.70  15.45  15.55  14.95  20.00  18.80  13.13  13.34  10.41  9.35  11.15  11.22  11.56  11.08  10.21  9.22  9.58  9.49  11.65  14.48  15.08  13.55  15.36  13.00  13.36  14.04  11.73  11.05  12.29  12.90  14.95  14.73  13.96  13.85  18.42  20.93  18.63  13.95  12.70  14.49  15.18  14.94  17.32  19.17  21.73  18.22  13.68  15.48  17.95  15.54  14.14  13.12  13.37  16.95  16.50  17.19  17.74  17.05  17.26  16.08  14.89  15.27  13.85  14.13  15.41  12.50  15.08  13.68  13.44  15.93  17.55  16.37  14.25  16.34  16.42  20.49  16.48  16.04  14.69  13.99  14.44  16.50  16.62  15.11  14.82  14.95  14.53  13.24  13.06  15.62  17.45  18.05  16.95  15.66  14.75  14.58  13.35  12.93  10.80  9.87  11.04  11.57  11.58  15.20  14.13  14.78  10.50  13.19  11.95  15.65  12.73  17.23  14.85  13.04  16.62  12.88  14.84  12.56  12.12  13.11  14.57  10.95  13.33
  ]
  set temp-86 [4.29  3.38  2.34  3.10  3.86  3.59  4.14  3.83  4.20  3.43  0.19  -0.97  1.80  2.75  5.97  8.58  8.89  5.88  5.06  5.51  6.49  8.57  9.09  9.55  9.48  10.71  10.78  9.30  9.31  9.24  11.05  14.92  18.45  13.17  12.38  12.42  12.77  11.28  11.10  12.78  11.65  12.58  13.25  10.90  10.70  10.03  9.73  15.83  13.60  15.79  18.04  12.79  11.66  11.64  12.32  15.40  12.94  11.52  9.78  9.02  8.74  11.80  11.65  12.03  10.47  8.36  9.52  11.03  9.95  13.10  19.15  13.45  11.57  11.77  15.28  18.24  21.05  23.52  17.09  13.50  13.27  12.60  16.81  18.00  18.48  16.13  17.21  19.01  17.26  17.15  18.57  19.97  20.36  21.66  17.36  17.46  15.35  14.20  12.89  13.15  12.85  12.46  12.13  12.71  13.68  17.85  19.05  19.69  13.45  12.90  13.48  16.43  14.57  14.45  13.11  13.62  15.41  18.63  18.51  20.02  17.64  17.13  16.62  16.94  17.25  21.21  15.90  15.09  17.42  16.08  15.55  14.76  15.01  17.28  17.20  17.43  18.98  16.00  15.74  12.77  13.41  13.32  12.02  13.88  14.44  12.64  12.64  13.76  13.45  12.82  11.84  13.73  12.51  11.91  13.68  12.90  12.57  11.71  11.87  10.67  11.47  10.19  8.14  7.74  7.95  8.57  13.17  9.00  9.84  8.57  9.73  9.14  9.62  12.75  12.73  14.33  12.80  9.98  9.22  11.78  9.32  14.21  13.95  
  ]
  set temp-87 [5.15  6.53  7.40  8.95  7.81  5.90  10.39  10.47  9.99  7.46  5.27  4.53  5.46  7.58  7.62  9.21  7.15  11.21  12.71  9.93  8.37  7.40  10.72  12.73  11.60  10.45  11.01  12.87  16.76  17.24  13.16  10.34  5.75  7.16  7.65  8.09  8.10  7.45  11.03  9.64  6.64  9.39  6.38  6.04  7.94  8.12  6.32  9.78  9.14  7.39  8.02  9.08  12.52  12.56  11.97  12.62  10.22  9.00  9.55  8.62  13.17  11.06  11.89  12.61  13.69  12.58  12.84  13.70  11.52  10.61  11.38  13.57  12.08  12.90  12.83  10.83  10.76  10.23  10.48  9.16  11.33  11.28  13.98  13.02  11.03  11.99  14.09  13.15  16.77  20.76  21.69  15.81  14.05  14.53  15.33  17.48  20.25  21.35  17.14  13.16  12.61  17.13  16.58  14.53  14.73  18.00  19.83  19.02  16.93  16.95  16.20  16.59  17.33  17.20  14.73  12.89  11.40  12.73  13.47  14.05  15.39  14.73  15.79  14.24  12.76  12.70  12.42  11.31  11.02  13.54  14.22  12.90  12.53  14.05  13.86  17.56  15.75  15.21  18.40  18.11  17.37  15.53  19.48  21.07  19.81  18.62  18.92  15.03  14.80  15.30  15.95  13.58  14.77  13.93  15.91  15.28  16.80  15.56  15.14  15.14  12.66  13.31  14.10  13.36  16.50  14.67  14.12  14.02  12.00  14.82  16.90  10.75  13.33  16.39  19.13  13.36  12.45  10.53  9.93  10.08  8.47  9.29  8.35
  ]
  set temp-88 [7.00  5.56  5.20  5.74  4.99  6.00  7.11  6.68  3.37  2.81  8.51  6.38  5.07  4.06  10.03  12.77  12.86  10.97  15.21  14.45  10.26  6.93  3.75  3.51  3.27  5.70  7.03  6.18  7.04  12.10  13.73  14.62  12.68  11.01  11.84  11.28  12.13  15.11  17.33  17.07  13.82  16.04  18.63  18.11  18.00  17.13  14.60  8.40  7.58  8.16  7.58  9.25  12.88  14.52  16.18  20.86  16.12  14.22  14.75  13.63  12.28  12.96  12.58  14.95  12.87  11.15  11.75  12.46  14.61  14.40  16.79  14.23  13.87  15.61  13.05  14.38  13.59  14.93  14.14  13.18  13.81  15.61  15.80  13.26  14.19  14.23  14.68  15.30  16.12  15.55  15.66  18.01  14.98  13.31  16.72  15.75  15.53  15.34  14.63  14.00  15.61  17.32  14.85  14.37  14.26  14.78  14.51  15.10  14.52  13.78  14.99  14.58  16.84  19.50  19.46  15.96  16.51  14.11  14.66  15.90  14.47  14.37  15.82  14.58  13.12  14.00  15.19  18.68  17.18  17.72  18.51  18.88  17.87  16.27  16.12  17.47  17.46  13.95  13.23  15.41  19.06  15.43  13.93  14.63  13.33  13.87  13.86  13.25  12.59  19.68  15.66  13.57  15.73  14.50  15.40  12.76  13.33  12.40  14.13  12.82  14.93  15.50  14.50  14.85  11.65  11.75  12.65  12.78  13.12  13.69  13.83  13.73  13.51  12.77  12.56  13.54  12.09  10.65  15.53  15.07  15.70  11.80  8.88
  ]
  set temp-89 [7.45  2.85  1.73  1.83  3.77  3.71  5.95  6.96  7.15  10.62  10.62  11.35  8.80  8.45  8.29  6.89  6.58  3.98  5.96  5.53  5.84  6.62  5.70  2.86  7.36  4.96  4.55  4.21  4.88  5.92  10.28  13.34  9.95  12.28  11.40  9.73  8.50  10.24  12.08  8.24  9.49  10.35  8.78  9.68  12.33  13.99  11.83  14.81  18.23  17.35  17.52  15.50  17.49  19.70  21.12  16.22  11.88  12.47  10.95  11.84  8.37  9.20  10.90  9.75  10.12  10.79  9.92  11.72  10.44  11.70  14.68  17.91  17.96  18.64  19.56  19.20  17.57  17.29  16.43  20.06  19.11  18.40  18.37  17.30  15.65  16.67  19.67  17.85  14.42  13.08  12.36  14.34  16.00  17.04  17.27  19.65  21.39  23.93  20.29  17.88  14.83  13.93  15.68  15.18  13.57  14.50  14.15  12.94  14.98  14.31  14.12  15.49  17.85  18.75  17.77  18.20  18.89  18.29  15.60  18.63  17.75  14.93  12.38  12.94  13.93  14.25  14.60  15.96  17.03  16.80  16.44  19.61  15.81  16.99  16.76  17.98  20.70  18.68  17.84  16.18  16.82  20.17  18.98  16.74  14.71  15.01  15.97  11.70  12.87  13.40  13.38  14.26  16.17  15.05  12.12  10.64  11.81  12.69  14.10  15.08  16.83  17.50  16.30  15.79  15.14  13.43  14.48  12.34  17.64  19.13  18.27  18.30  14.12  16.05  18.95  16.28  14.55  15.15  14.17  11.16  11.40  12.31  12.92
  ]
  set temp-90 [11.64  12.37  9.13  3.74  1.77  3.51  5.20  5.54  3.36  3.00  8.13  7.86  9.33  9.57  6.34  6.52  5.31  5.68  5.60  7.51  11.21  12.72  11.70  10.94  12.29  9.88  8.65  6.39  11.35  11.78  11.65  15.23  18.42  18.04  18.78  19.13  18.35  13.32  14.40  13.48  10.10  9.79  10.22  10.45  11.35  15.11  11.84  10.06  10.73  13.65  14.16  10.67  9.93  11.14  9.19  8.32  8.98  9.59  9.42  12.71  14.87  15.50  16.49  12.97  12.18  12.29  14.26  14.43  11.54  11.43  12.80  12.04  12.06  12.32  12.22  12.37  12.39  13.58  15.67  18.01  16.47  15.75  14.68  14.43  15.04  16.13  18.12  19.65  18.28  15.19  18.47  16.15  13.86  12.64  12.77  14.62  12.46  11.76  15.71  15.70  13.52  14.49  17.25  14.14  13.32  16.72  17.15  14.99  14.18  15.56  17.67  17.21  14.66  13.95  13.85  14.33  16.46  19.52  21.85  18.64  19.26  21.25  19.67  20.07  23.58  24.54  19.33  14.10  13.21  13.45  17.62  17.75  18.42  18.18  21.24  18.40  17.43  18.82  13.31  12.89  12.83  15.73  14.22  15.42  17.48  15.87  17.97  17.89  17.75  20.01  20.00  19.15  13.41  13.85  14.94  15.65  15.20  12.54  12.42  11.98  12.33  13.03  13.65  12.62  12.95  12.66  11.99  12.33  12.49  12.20  10.74  13.98  9.85  9.93  9.64  10.33  10.84  9.93  10.03  8.73  10.95  12.81  14.41
  ]
  set temp-91 [9.26  9.33  10.15  7.73  9.79  8.50  8.76  8.15  7.81  10.39  13.47  13.85  14.06  12.43  11.58  6.68  5.86  3.42  3.60  2.03  1.70  5.23  4.84  4.89  7.53  8.12  5.91  4.28  6.92  5.59  6.83  7.01  6.51  6.31  5.48  7.60  8.43  8.39  7.01  9.05  8.96  9.83  10.53  11.23  7.22  7.20  8.19  7.36  8.62  13.12  14.46  12.68  9.08  8.88  9.03  9.96  10.03  10.27  10.20  11.53  10.32  9.73  7.88  8.45  7.20  8.38  11.23  12.82  11.78  11.98  12.81  12.62  12.69  13.11  12.47  11.53  11.94  11.53  11.17  10.35  12.11  12.63  16.40  14.60  14.30  14.62  15.95  13.61  12.50  12.13  13.30  16.26  18.32  22.26  21.38  20.50  23.63  24.26  22.85  18.40  16.59  21.75  21.08  17.21  17.22  14.39  16.50  15.92  13.67  15.91  16.24  15.17  14.42  17.31  17.93  15.35  15.77  16.70  19.00  21.04  22.19  20.23  17.99  18.98  17.57  18.44  18.74  21.64  20.40  17.12  15.87  18.71  18.85  16.43  14.93  16.00  17.82  18.27  15.45  14.67  14.45  16.28  15.71  20.16  20.99  17.40  15.37  16.07  14.74  15.52  14.57  14.82  16.24  18.97  20.14  20.21  18.68  15.69  13.95  14.79  15.10  14.75  14.38  13.40  10.83  11.71  12.89  16.36  12.18  15.94  13.70  13.55  11.98  12.22  15.68  12.57  16.53  14.25  14.27  12.34  12.05  12.76  12.97
  ]
  set temp-92 [7.05  6.27  5.66  4.03  4.20  6.64  7.94  9.20  7.96  7.46  10.42  9.03  7.35  6.94  7.72  4.43  3.21  8.21  9.35  5.95  6.72  9.72  8.53  10.47  12.40  10.77  11.31  9.23  8.94  8.20  9.85  7.94  7.93  7.28  11.18  10.91  13.00  11.39  7.66  7.52  8.90  9.11  14.05  17.38  20.71  13.52  10.29  12.79  17.03  18.57  19.50  19.84  21.18  21.58  20.54  17.55  17.76  19.49  19.40  19.57  19.68  20.38  20.42  17.52  13.29  15.80  19.16  17.99  17.01  17.15  17.30  15.53  16.17  16.95  17.60  19.56  18.01  15.20  13.22  10.57  17.89  14.93  14.24  13.77  14.57  16.22  16.55  19.21  20.14  21.80  23.17  20.37  16.89  15.87  18.53  17.00  17.65  16.80  15.15  17.54  18.95  17.08  16.77  14.57  16.34  14.71  16.14  18.32  17.90  19.93  21.77  22.14  17.59  17.50  20.33  18.55  17.83  17.08  15.33  15.67  18.38  16.83  18.48  19.62  18.69  17.23  17.05  18.50  14.90  19.61  25.51  20.48  16.78  16.02  15.18  14.62  15.18  15.50  16.26  15.10  17.22  16.59  18.48  16.65  17.18  14.79  16.73  17.39  17.75  19.26  14.93  13.75  14.05  12.49  11.87  14.66  11.69  12.72  11.77  14.55  11.27  12.37  15.04  15.00  12.38  12.17  12.66  13.73  15.20  11.05  12.64  15.25  14.53  14.75  16.61  16.35  13.86  16.37  15.41  16.29  16.05  13.53  12.63
  ]
  set temp-93 [11.58  8.33  6.25  5.63  5.67  7.26  6.93  5.70  7.09  7.12  6.32  6.14  7.04  7.86  7.99  6.75  10.44  9.23  7.48  11.06  15.24  12.59  13.11  16.50  16.65  14.11  13.68  15.23  19.28  19.38  19.30  13.63  9.35  6.43  7.24  7.23  10.31  11.63  14.46  18.47  17.87  17.81  13.44  11.05  10.88  10.50  15.93  18.78  16.25  16.80  16.25  13.18  11.47  12.99  14.20  13.93  11.70  11.40  12.55  15.05  13.73  14.61  15.67  13.54  14.13  17.04  15.21  15.18  15.00  17.26  21.80  21.80  15.38  14.12  12.10  12.11  12.80  13.88  14.32  16.18  14.62  13.44  12.53  11.08  10.44  11.80  11.52  14.98  13.10  13.84  15.00  16.17  15.78  15.93  19.45  15.79  13.05  12.97  14.64  16.22  14.52  12.06  11.73  11.90  12.54  16.01  15.58  18.22  16.29  15.54  14.50  13.74  14.33  13.89  18.40  15.90  13.76  12.85  17.08  15.63  17.63  15.77  14.13  16.54  16.76  15.70  15.66  14.78  14.28  15.93  13.49  15.21  11.70  16.14  14.00  14.86  16.95  17.02  13.54  12.93  14.06  14.98  16.60  12.08  10.50  12.37  12.17  12.77  12.40  12.16  11.80  14.02  13.64  12.61  13.16  13.33  12.17  12.48  10.12  10.58  11.47  15.02  14.67  13.71  11.36  12.50  11.53  13.75  11.76  10.35  8.32  9.73  13.44  16.60  13.27  12.78  10.95  11.52  11.76  12.52  11.63  10.48  10.73
  ]

; DATA MARKNESSE

  set temp-94 [9.74 7.10 5.29 6.32 4.18 5.01 5.16 6.95 5.90 3.86 8.22 8.18 7.89 5.80 6.26 6.66 5.87 5.28 4.21 7.05 8.53 8.79 13.84 13.93 11.24 9.30 12.90 13.55 14.18 14.34 8.41 7.74 11.14 13.95 11.86 11.03 14.02 14.01 9.76 9.33 11.76 16.78 15.94 16.68 15.43 12.47 11.10 12.97 11.72 12.85 13.57 13.15 12.64 12.20 13.23 11.75 10.36 10.70 9.52 9.85 11.46 15.40 17.71 14.06 12.47 11.06 11.60 14.19 13.56 10.70 11.57 11.68 12.50 12.59 14.69 12.53 13.06 11.95 14.44 15.12 16.31 15.60 16.81 14.21 14.74 19.95 18.45 17.75 19.70 21.05 15.94 16.65 19.58 22.66 21.47 19.26 16.42 15.96 15.87 16.45 18.14 20.53 22.64 23.26 21.49 18.97 19.35 18.00 16.44 19.23 19.91 20.40 22.15 22.13 23.00 24.16 22.30 23.48 22.46 20.12 20.58 24.48 22.15 19.68 21.74 24.05 23.81 20.38 17.74 16.87 16.72 17.87 19.14 16.97 15.39 13.77 14.15 13.93 15.12 14.16 15.50 15.78 15.22 16.11 17.94 17.85 16.68 16.96 16.39 14.84 15.26 14.38 16.53 17.38 16.18 15.53 15.76 16.08 13.04 12.15 14.10 13.05 13.09 11.96 14.37 14.78 12.58 13.36 12.60 11.94 13.09 12.34 12.09 12.88 11.97 12.17 13.70 15.13 13.81 13.38 11.46 13.43 13.78 
  ]
  set temp-95 [9.42 11.32 9.35 8.73 5.99 9.87 9.39 6.08 4.90 7.30 8.31 9.50 8.78 8.66 7.25 6.68 6.98 8.18 4.95 4.78 5.64 10.20 11.60 13.90 16.54 14.33 8.84 6.76 8.13 9.09 10.51 13.85 15.45 16.28 17.18 15.08 14.75 14.65 10.40 9.21 8.40 6.89 8.75 7.59 9.10 8.99 9.32 8.65 7.32 9.38 8.94 9.38 13.66 16.94 17.15 16.05 15.90 17.53 16.63 14.60 14.37 13.57 12.53 13.61 14.51 13.53 12.86 12.26 10.86 10.78 11.42 11.31 12.13 12.87 12.31 10.99 10.65 11.96 14.55 14.90 17.41 16.48 12.11 13.68 15.13 17.41 19.00 19.98 22.35 18.08 16.65 17.06 15.26 15.20 13.28 14.65 17.36 17.50 18.99 19.94 22.52 22.95 22.80 21.19 20.96 18.86 18.88 17.53 17.23 19.97 20.96 22.67 18.74 14.98 17.57 17.50 19.55 22.09 18.73 20.93 23.07 23.90 23.95 22.27 21.53 18.45 17.40 20.31 18.01 17.63 16.92 18.76 20.75 22.18 19.88 17.50 16.34 18.98 20.53 20.80 22.23 21.18 19.93 20.98 22.27 19.60 18.45 18.04 15.12 13.45 13.90 13.40 13.10 14.64 15.55 15.30 13.94 15.15 13.89 14.40 15.45 15.69 16.10 16.53 15.48 13.96 14.54 13.24 15.14 14.95 14.45 15.78 13.51 12.23 14.50 14.99 13.11 13.25 13.58 12.03 9.58 9.40 9.10 
  ]
  set temp-96 [-0.13 -0.22 1.39 3.94 5.35 7.33 6.88 6.33 6.60 9.46 8.69 2.43 2.54 5.07 7.51 10.90 11.95 11.20 12.65 14.50 16.90 17.96 17.80 11.61 10.30 10.75 13.40 12.14 6.91 7.58 10.58 10.71 8.65 7.37 6.67 6.61 8.74 8.13 8.13 7.13 7.45 8.22 8.55 9.50 8.28 5.93 7.83 8.72 12.92 11.23 10.88 11.00 11.88 13.85 13.18 12.87 11.95 9.38 13.27 17.77 19.04 14.13 12.98 15.08 15.46 18.04 22.14 23.62 24.13 16.40 17.15 20.85 17.68 13.38 11.76 12.06 13.41 14.08 15.38 12.33 11.54 10.49 11.30 11.18 11.48 11.84 14.17 14.86 13.06 13.95 13.18 14.41 12.90 14.51 16.31 15.02 12.80 12.85 12.32 13.11 14.58 15.60 16.73 17.25 17.17 15.27 14.10 14.17 13.33 14.45 17.10 18.38 19.35 19.05 16.81 16.42 16.08 16.46 14.00 17.61 16.38 17.35 16.54 15.79 14.05 14.70 17.41 17.45 15.67 16.42 17.95 20.98 18.40 17.88 18.23 18.50 17.70 17.08 16.16 17.24 19.97 21.39 19.79 18.46 18.03 17.44 15.56 15.63 15.21 14.69 13.95 15.35 15.25 12.64 12.91 14.36 14.26 14.52 12.72 11.38 11.77 13.50 13.35 12.94 13.15 11.19 13.43 11.96 11.44 10.60 11.45 9.30 10.30 9.82 9.64 10.44 10.26 10.13 11.13 14.60 12.40 13.43 15.97
  ]
  set temp-97 [8.38 7.73 9.05 5.98 6.83 6.49 3.23 5.98 9.55 8.61 8.31 6.42 4.73 8.39 6.91 6.41 6.08 6.44 6.52 4.53 3.20 5.50 5.04 9.05 9.68 9.22 11.67 11.46 10.09 9.60 10.20 13.74 12.05 13.83 13.57 9.29 5.67 6.54 8.64 10.16 13.41 12.55 13.05 13.04 10.77 16.20 20.98 20.01 16.79 17.12 13.33 10.88 9.35 8.93 10.36 10.23 11.23 10.78 10.32 12.85 14.21 13.75 16.36 15.73 14.55 17.61 21.44 22.26 17.76 16.60 15.82 18.75 18.27 17.57 16.13 13.49 12.12 11.98 12.14 14.64 14.82 14.69 13.63 13.10 12.90 12.43 13.37 15.19 14.49 15.81 15.53 14.28 14.78 15.75 15.38 16.24 14.50 17.18 16.82 16.85 16.84 18.96 20.26 19.35 19.29 17.97 17.42 17.17 16.45 18.17 18.37 18.42 19.18 18.39 17.59 17.16 17.87 18.00 16.61 17.71 18.38 16.02 16.75 18.48 17.38 17.64 16.54 20.11 20.85 21.00 21.68 21.75 23.03 22.94 22.37 21.15 20.66 18.60 20.41 21.34 20.83 20.44 20.79 20.53 20.11 23.10 22.25 19.66 18.14 17.60 16.21 15.11 18.16 18.91 16.81 15.86 18.00 16.70 15.75 15.84 15.89 16.00 13.68 12.43 15.86 13.08 12.64 13.65 14.68 15.08 13.77 13.73 9.38 9.45 10.44 10.60 13.71 11.98 13.56 13.19 9.00 10.13 15.36
  ]
  set temp-98 [8.24 9.30 10.84 9.39 10.43 9.43 8.00 8.43 7.35 7.92 8.10 6.65 4.66 3.47 4.73 5.97 7.07 9.14 7.50 8.46 9.76 12.41 13.98 12.04 12.30 11.11 10.41 10.76 10.34 11.58 11.60 12.70 9.50 8.67 9.94 10.80 12.55 14.75 18.29 18.34 20.37 21.77 20.17 17.47 16.06 15.48 14.80 16.20 14.63 13.35 11.69 10.23 9.75 11.63 12.65 13.02 13.05 14.59 16.12 14.67 15.29 15.40 17.28 15.92 14.38 11.85 15.92 17.08 15.45 15.89 15.89 13.32 11.99 11.28 13.43 14.48 13.69 13.66 13.92 15.61 18.78 22.70 18.34 15.26 17.30 19.03 15.80 16.95 15.17 15.72 14.41 15.28 14.61 14.19 14.96 15.57 15.70 12.86 12.67 14.53 15.59 15.52 15.27 16.33 13.43 14.59 14.75 14.04 15.55 16.04 19.40 21.68 16.61 17.89 16.96 14.80 14.61 18.40 16.44 15.32 15.59 15.35 15.64 15.36 15.22 17.53 16.54 16.34 18.25 19.02 18.23 18.18 21.86 19.78 16.21 16.15 18.42 14.59 17.27 17.97 14.24 15.45 16.47 14.92 13.84 14.88 13.83 12.48 12.00 12.49 12.98 14.14 13.17 14.50 16.01 16.70 17.15 16.12 15.22 15.75 17.31 17.17 17.35 15.00 11.84 9.32 8.68 13.68 12.93 13.06 13.00 15.60 15.50 14.06 14.00 11.26 12.32 15.05 15.71 16.61 13.04 13.88 13.57
  ]
  set temp-99 [12.65 13.33 11.08 10.86 9.97 11.88 10.19 8.72 8.59 10.32 9.17 7.98 6.97 3.09 3.23 5.02 5.96 5.82 5.21 6.96 12.03 11.36 10.99 12.78 12.05 13.72 13.12 11.92 10.30 8.75 10.29 9.41 11.15 11.20 13.27 10.62 12.56 14.84 14.83 14.69 13.73 13.20 13.65 12.50 10.31 8.82 11.79 14.38 15.81 16.33 15.20 13.91 13.32 14.22 13.88 12.74 15.55 19.08 18.42 17.33 12.57 13.18 16.36 16.95 14.37 12.70 13.18 13.05 13.25 13.18 13.84 12.85 13.08 14.93 16.75 16.60 17.33 17.78 14.01 13.81 16.07 12.84 11.93 11.98 14.01 12.45 14.04 17.15 16.00 15.91 17.11 14.24 17.35 19.20 18.03 18.12 16.55 17.09 18.54 17.43 19.06 21.98 21.72 21.44 17.32 15.39 16.03 17.46 19.13 21.35 20.28 18.10 15.52 14.45 17.65 19.11 16.05 14.78 16.10 18.88 20.56 21.34 21.78 21.98 22.60 21.77 20.41 19.94 18.11 18.50 18.15 17.36 15.80 15.16 14.06 15.85 16.06 15.13 13.35 15.50 14.47 15.75 14.57 13.90 14.66 13.84 18.48 21.13 17.41 16.71 15.99 16.50 15.14 16.03 17.31 17.60 17.27 18.15 17.92 17.76 18.68 18.73 16.94 20.64 21.11 18.31 18.67 17.33 16.28 15.87 14.17 15.83 18.31 16.29 15.59 17.80 17.48 15.74 15.23 13.83 14.84 15.18 15.15
  ]
  set temp-00 [5.59 6.89 10.41 11.00 4.99 3.73 5.53 5.16 7.86 5.31 4.84 6.88 5.52 6.19 6.61 8.50 9.58 9.92 11.63 12.05 14.32 13.02 12.88 11.30 12.65 15.49 14.39 17.14 13.59 11.82 11.88 9.75 10.75 12.23 14.51 17.95 18.95 18.66 18.81 19.45 17.80 15.68 16.80 17.97 20.77 21.48 16.03 11.88 10.93 10.38 9.64 11.54 12.40 14.13 13.20 12.42 13.21 10.55 10.18 10.35 11.50 13.70 15.27 14.79 17.60 13.35 12.52 12.35 12.90 19.00 19.58 14.88 15.37 16.48 15.84 15.48 12.36 12.18 18.60 23.23 25.83 22.53 16.63 15.49 13.42 13.02 12.35 12.40 12.31 12.40 12.83 11.88 16.09 19.22 17.99 16.76 15.45 13.69 12.82 13.19 14.51 13.68 12.95 13.30 14.30 12.87 13.66 13.38 12.87 14.47 16.32 15.34 15.53 15.79 17.23 17.71 16.48 15.80 17.19 16.47 16.52 16.54 20.02 18.91 17.58 16.42 15.45 16.83 17.45 16.34 16.05 18.26 18.38 17.16 18.12 21.90 19.90 16.96 17.60 16.50 17.97 18.05 15.11 14.85 14.45 13.40 16.43 17.28 17.68 15.91 14.55 14.15 13.74 14.24 14.65 14.72 14.16 14.38 14.83 15.25 15.79 15.77 15.54 16.85 17.63 15.49 15.33 16.45 16.78 14.26 15.06 15.86 12.21 10.93 11.93 15.24 13.51 14.06 13.77 16.46 14.90 17.10 14.78
  ]
  set temp-01 [11.40 11.91 12.63 9.84 7.85 9.15 9.77 7.14 6.63 9.33 8.74 5.38 4.06 1.50 5.23 6.31 5.70 5.30 4.29 3.75 4.74 5.49 7.87 9.53 10.20 9.49 9.87 9.85 10.77 13.37 10.13 10.68 12.72 8.91 7.00 8.95 10.20 9.24 13.96 17.81 18.06 16.73 17.35 17.23 14.06 13.86 12.91 11.43 11.98 12.03 11.22 12.06 14.22 15.63 13.41 15.44 15.28 16.15 16.80 15.86 14.56 12.98 12.06 9.39 11.19 13.16 15.30 13.95 12.03 10.78 12.48 12.12 14.40 12.85 13.44 16.20 16.06 15.25 14.19 13.15 15.41 15.89 13.78 13.59 15.48 15.80 17.65 19.85 18.04 18.57 19.15 17.27 16.58 17.96 20.45 23.04 23.84 21.60 18.81 18.03 17.63 15.90 16.44 14.46 14.49 14.39 14.22 14.25 16.40 15.80 15.22 13.80 18.61 16.68 18.53 18.04 19.20 21.51 20.04 18.59 20.66 19.92 17.35 17.14 19.86 17.21 15.68 15.93 17.92 16.88 15.57 14.50 14.45 15.75 17.11 20.50 22.84 21.91 17.37 17.48 20.29 18.90 16.62 20.40 21.72 22.86 23.25 23.03 18.53 14.86 13.98 15.31 16.38 15.25 14.19 16.18 14.13 14.51 14.89 14.51 14.00 11.84 13.22 12.58 14.08 14.16 12.81 12.91 11.38 11.25 10.23 11.38 11.80 12.87 12.50 12.60 12.75 10.61 11.83 13.31 16.74 14.52 15.91
  ]
  set temp-02 [10.71 12.83 13.43 11.10 8.65 5.37 4.91 6.71 6.16 6.43 7.67 6.73 7.74 6.38 7.43 7.89 8.72 8.19 8.51 9.03 9.00 12.83 13.74 13.67 10.81 9.06 8.41 8.75 9.34 9.71 11.16 9.60 9.83 8.76 8.26 10.27 12.16 12.13 14.97 16.18 13.18 12.32 13.62 15.23 13.28 15.18 14.41 13.19 14.58 15.70 18.72 18.15 15.45 13.90 12.29 12.21 12.30 14.39 14.19 13.08 13.68 12.10 15.40 18.62 16.78 20.74 17.28 16.75 15.89 16.95 14.53 13.40 13.42 13.75 15.54 18.29 16.44 21.25 24.35 17.15 16.29 15.79 15.83 16.62 15.26 15.68 15.42 15.44 13.40 13.65 14.40 14.20 14.11 13.85 15.56 14.83 15.49 14.74 17.32 19.88 15.74 14.38 15.32 16.60 19.06 19.30 19.29 18.45 15.91 15.31 14.67 16.11 15.55 16.87 16.81 15.78 17.48 19.03 22.37 23.45 24.00 22.04 19.53 18.34 17.83 17.18 17.48 17.84 17.99 18.35 18.44 17.44 19.08 17.43 18.23 18.98 20.10 21.13 21.47 22.33 21.81 21.42 18.79 17.67 16.73 16.61 18.23 16.69 20.15 20.27 18.06 17.84 18.40 15.85 14.51 16.40 16.24 15.13 16.64 17.91 17.39 18.58 15.79 16.60 16.43 15.43 15.93 15.73 13.28 15.29 14.73 14.41 14.32 13.46 12.95 12.06 9.84 12.95 12.44 13.34 12.60 13.23 10.93
  ]
  set temp-03 [6.46 6.93 5.15 4.16 7.00 4.58 2.38 1.55 1.33 2.16 5.19 5.83 8.13 12.77 14.98 16.64 14.78 12.57 7.72 9.44 13.58 13.00 11.31 12.16 16.32 14.57 11.65 12.96 14.80 12.33 11.72 12.54 11.07 13.86 15.33 12.33 10.98 12.53 11.24 12.05 13.33 12.43 10.51 9.44 10.03 10.08 13.22 14.11 13.40 11.37 12.21 12.78 13.43 12.82 13.43 12.93 14.50 16.38 17.89 20.48 18.64 19.77 21.93 18.55 22.23 17.70 16.31 19.74 18.77 16.45 17.25 17.83 16.03 16.15 15.33 15.46 16.13 17.13 18.87 17.50 16.05 15.16 15.30 19.45 16.55 14.68 14.69 18.95 18.49 15.58 15.79 15.45 15.80 15.53 15.25 15.00 15.00 16.46 16.41 17.25 16.41 20.26 16.14 15.78 18.57 21.33 24.14 20.10 18.39 20.89 22.86 19.97 19.42 18.80 18.93 17.79 18.75 19.60 17.50 17.96 19.88 18.50 19.65 20.37 19.17 18.95 19.60 21.39 23.50 23.71 21.52 20.81 21.89 23.84 22.23 18.60 17.03 15.37 15.37 20.02 19.25 15.85 15.68 17.10 19.56 17.00 17.94 16.20 16.50 15.03 14.14 14.07 13.76 13.38 13.03 12.60 13.73 15.33 16.54 15.78 14.14 15.52 12.41 13.36 13.46 12.70 12.82 13.41 15.69 16.53 18.16 17.43 16.60 18.00 19.65 13.13 10.35 10.48 11.42 12.85 10.08 11.85 9.68
  ]
  set temp-04 [11.44 12.49 11.50 10.86 8.35 6.15 6.24 5.86 6.52 6.18 6.05 6.21 8.58 7.18 10.81 12.79 14.29 11.77 9.21 8.57 11.45 13.95 11.25 11.49 10.65 13.34 14.60 15.20 14.00 15.60 15.69 12.53 13.17 11.15 10.80 10.63 10.11 11.41 11.55 12.37 11.76 10.33 10.43 11.68 14.28 14.14 15.11 15.68 14.80 15.32 11.73 9.15 10.17 11.19 12.02 10.35 11.07 10.96 15.17 18.18 14.09 14.11 14.82 13.22 13.93 13.59 14.14 17.85 19.89 21.15 18.70 17.92 15.30 13.98 15.21 17.64 14.45 15.79 14.20 12.58 11.65 11.91 14.10 16.02 13.48 13.92 13.83 16.78 16.53 14.90 16.57 16.97 14.22 14.92 15.12 15.09 14.21 15.15 16.48 15.15 14.98 14.21 13.90 13.74 14.41 16.55 17.23 19.22 18.45 17.31 15.66 17.01 19.20 20.10 16.64 14.96 15.29 15.19 16.82 18.30 20.04 19.54 18.23 18.18 19.75 20.20 21.65 23.46 22.64 22.83 24.23 23.60 20.02 19.64 17.28 18.18 19.13 19.26 18.70 20.37 19.22 16.77 15.32 14.09 14.15 16.39 16.27 16.31 14.81 15.58 13.77 14.80 14.61 13.95 15.12 16.38 18.78 18.19 18.45 17.69 14.67 14.96 16.00 18.93 16.53 15.53 14.43 13.58 12.42 13.57 15.90 15.66 13.12 13.92 11.61 12.53 11.68 12.10 13.13 14.89 14.25 13.73 12.32
  ]
  set temp-05 [8.98 9.70 12.38 13.14 9.70 7.78 8.60 7.55 4.18 7.55 9.51 9.77 9.97 11.57 12.99 9.05 10.29 11.13 7.90 8.21 7.52 7.09 9.07 11.30 11.98 10.77 11.02 11.28 13.88 12.69 16.23 17.30 13.01 12.37 9.16 10.59 8.70 7.77 8.25 8.52 8.49 7.78 10.10 11.07 10.56 9.84 7.04 7.64 11.03 15.38 15.63 15.05 14.07 12.39 15.83 20.05 19.73 22.38 15.80 11.85 11.74 11.31 15.01 17.14 14.33 14.25 11.85 10.48 10.98 12.39 12.85 11.10 10.86 11.67 14.15 15.52 16.53 18.23 16.96 19.20 22.87 21.75 18.44 20.85 24.54 20.76 15.32 15.25 16.08 16.22 18.02 16.16 16.72 19.32 19.29 14.70 14.11 15.50 15.07 15.75 20.40 19.31 19.28 19.04 18.99 20.69 16.83 15.66 19.02 18.17 16.55 15.60 14.54 14.38 14.76 17.35 15.70 14.46 20.52 22.00 18.49 15.33 15.44 13.86 14.55 16.25 14.66 13.19 12.99 14.85 14.26 14.79 15.50 13.76 14.09 16.04 15.72 14.41 16.04 18.60 20.30 18.13 17.64 16.65 15.60 14.47 16.08 13.64 14.85 16.28 18.05 17.10 20.50 20.72 18.40 17.36 16.98 20.00 18.89 19.98 19.97 19.73 19.56 17.70 17.67 14.59 15.80 15.56 12.62 10.67 10.47 12.07 12.32 13.16 13.85 13.75 16.28 15.29 15.05 14.68 14.03 11.97 11.01
  ]
  set temp-06 [10.93 8.33 8.40 6.09 3.79 5.17 7.54 7.38 6.26 5.63 4.30 6.64 8.67 8.94 6.99 10.40 10.06 9.54 9.41 11.19 13.06 9.78 9.56 11.63 14.31 13.30 11.19 8.00 7.27 6.60 7.44 11.13 16.50 17.93 19.47 19.14 18.74 18.90 18.15 17.17 17.20 17.10 15.40 12.24 12.21 15.89 14.83 16.63 13.43 12.41 12.39 14.68 11.33 10.23 9.87 10.50 13.41 12.80 11.75 9.13 9.83 9.64 10.50 13.61 12.06 11.50 11.58 11.73 14.22 16.64 18.97 22.37 22.49 23.07 17.73 13.54 13.00 15.40 17.74 20.10 17.56 16.08 14.90 15.61 16.92 17.80 16.94 14.67 13.74 14.05 17.63 19.88 21.63 21.83 22.45 24.01 21.83 20.16 19.24 19.13 19.80 19.90 16.61 18.65 16.24 16.28 19.55 21.51 22.48 22.72 24.82 23.40 22.28 21.14 21.33 22.70 23.65 23.03 22.33 21.55 21.43 18.58 17.98 16.23 15.87 17.75 19.84 20.13 18.40 16.47 15.89 14.62 13.97 14.59 14.14 15.84 17.22 17.20 17.55 18.73 19.28 16.87 17.48 16.68 15.88 17.25 16.36 16.63 15.98 14.06 14.04 13.95 13.56 17.59 17.30 18.61 18.05 15.73 19.70 18.21 15.25 13.13 16.11 17.98 19.26 21.41 21.50 20.05 19.46 18.06 17.82 16.15 14.64 16.37 19.87 19.48 18.90 18.12 17.59 15.65 15.63 17.08 17.67
  ]
  set temp-07 [10.88 10.99 7.91 6.51 8.52 9.44 8.84 8.42 10.32 11.59 12.67 12.07 14.68 17.29 18.46 18.17 11.59 9.76 9.92 8.15 6.38 10.94 14.48 15.41 19.04 19.14 18.26 16.56 14.89 12.72 13.52 14.00 12.84 14.44 12.64 11.06 12.88 12.16 12.70 13.59 12.00 12.61 14.31 14.84 11.67 11.88 10.18 13.23 16.03 13.69 16.53 15.10 13.93 16.57 18.12 14.75 14.24 13.96 12.63 12.61 15.67 15.97 16.92 15.64 16.23 17.71 16.86 19.18 23.71 21.11 19.59 20.02 17.69 17.73 16.54 17.50 16.90 15.79 16.40 17.54 19.31 16.33 16.38 16.08 16.20 16.10 13.13 12.50 14.23 14.28 15.26 18.03 17.43 15.40 14.73 15.73 14.93 16.24 15.99 15.69 15.08 15.10 16.29 18.42 21.07 17.85 21.61 18.91 18.73 18.04 17.41 17.18 16.90 14.79 15.76 16.79 18.13 17.78 16.68 15.32 13.39 14.38 15.26 16.45 17.18 17.96 20.62 22.47 18.92 16.48 16.28 17.46 16.32 16.27 17.85 17.55 20.16 17.65 14.30 15.04 17.12 17.02 15.90 19.01 17.56 18.46 18.43 18.27 14.93 14.24 12.34 15.08 15.99 15.76 15.98 15.44 11.95 10.97 15.90 16.38 15.99 15.04 14.41 14.14 12.79 13.85 12.61 12.85 13.63 15.17 12.03 10.56 13.90 15.73 14.84 14.59 15.50 12.11 10.83 10.23 13.47 12.71 12.51
  ]
  set temp-08 [7.89 8.93 7.39 7.45 8.36 4.98 3.44 4.47 4.55 5.95 5.81 8.17 8.05 6.94 6.18 4.32 5.10 7.63 7.83 9.73 11.00 11.94 12.35 13.05 11.04 12.43 15.69 13.90 10.63 13.00 10.98 10.17 11.05 13.99 14.73 16.21 16.50 17.31 18.47 19.70 19.60 18.95 18.27 16.69 16.14 13.62 11.68 10.32 9.64 9.35 11.75 13.94 15.86 16.57 14.67 13.77 13.60 17.97 17.80 17.66 14.89 15.78 20.66 20.74 17.54 16.81 18.78 18.43 19.09 19.32 17.41 14.45 12.58 11.49 11.96 12.17 11.28 12.11 14.25 15.25 15.33 15.93 19.90 15.91 12.80 16.37 17.17 15.69 17.58 17.03 16.97 17.59 21.75 19.35 16.95 16.12 18.12 16.03 14.90 15.11 16.43 16.70 15.19 14.20 15.62 16.85 17.49 15.10 15.52 16.25 14.55 13.70 15.06 17.46 18.33 20.35 22.88 21.31 23.17 22.35 19.70 21.83 21.50 18.53 18.47 17.87 18.14 20.22 19.98 18.18 16.45 17.78 17.03 16.53 16.39 16.36 15.09 15.19 16.27 15.82 17.40 16.70 16.66 16.17 13.92 14.28 16.94 17.72 16.86 17.83 18.58 16.44 18.91 18.94 15.50 14.04 14.34 15.30 17.56 15.01 15.78 15.73 18.03 18.08 18.44 14.50 11.09 11.90 11.96 11.94 11.13 10.33 10.32 11.03 12.82 12.45 13.31 11.94 11.15 10.18 10.76 12.03 11.29
  ]
  set temp-09 [7.02 10.41 12.27 10.25 8.86 10.42 12.84 9.98 9.03 14.45 16.34 14.73 12.60 11.85 14.33 16.12 13.23 11.08 11.01 12.84 11.03 10.25 10.46 12.52 15.45 13.87 12.81 11.40 9.66 10.61 13.05 13.70 11.89 9.98 11.19 11.97 12.69 12.04 11.13 13.33 11.42 10.64 14.00 14.71 13.35 12.15 13.12 13.03 14.13 13.64 14.31 12.75 15.08 16.17 14.06 16.98 12.57 14.30 13.27 14.89 17.51 19.20 15.83 12.66 10.93 10.20 10.93 12.56 12.88 15.08 14.64 13.30 12.95 12.77 16.30 15.91 14.26 14.06 17.71 15.01 14.43 13.08 12.86 14.59 16.10 18.33 19.39 20.35 19.94 20.33 20.00 19.77 21.02 21.77 19.56 19.03 19.02 16.00 15.48 14.85 14.21 14.43 15.58 16.97 18.37 19.23 18.70 19.09 15.98 16.19 16.51 17.08 19.60 17.40 16.18 16.49 16.45 19.15 16.51 18.16 17.75 14.89 17.13 18.35 15.87 17.13 20.33 22.51 22.85 19.33 17.81 17.94 18.59 17.74 17.07 16.29 19.92 20.14 18.12 18.28 20.69 24.10 18.79 16.64 16.88 19.23 19.10 16.60 18.46 17.55 14.47 14.98 16.69 18.21 16.04 15.45 14.45 15.22 15.00 16.03 18.13 18.08 15.41 13.98 14.84 14.43 14.40 15.16 15.81 12.46 12.35 15.17 16.25 12.68 14.26 15.84 13.69 11.94 11.42 11.18 13.39 15.29 13.56
  ]
  set temp-10 [5.05 6.76 8.17 7.45 7.08 9.48 11.62 11.07 9.32 7.33 5.29 7.40 8.76 8.56 8.23 7.88 6.28 8.48 8.04 7.69 6.72 5.91 5.59 9.23 13.68 13.00 12.35 13.58 17.59 13.76 10.34 8.52 6.43 7.29 8.07 7.90 7.34 8.40 8.75 6.41 7.13 6.21 7.32 8.38 8.74 10.95 11.60 9.65 10.89 12.54 13.34 12.30 14.57 16.40 12.38 9.21 11.00 11.70 12.39 13.59 11.81 12.94 14.36 14.10 14.33 15.03 18.98 15.21 15.68 16.49 17.79 18.53 13.96 13.03 15.44 12.17 12.73 15.04 12.91 11.65 11.60 12.06 11.85 16.13 18.69 17.87 17.01 20.10 20.73 19.01 17.76 20.31 24.38 22.90 19.62 18.66 16.08 16.10 21.15 23.03 24.11 23.47 21.05 19.43 22.34 18.86 18.78 17.15 16.86 19.06 21.47 22.11 19.70 18.23 16.87 15.18 17.28 17.25 18.57 16.50 16.83 17.15 19.25 16.23 16.65 15.83 16.17 15.71 16.80 17.41 17.28 17.36 18.41 14.78 15.00 15.93 17.92 18.66 16.56 17.09 16.53 18.73 20.17 20.38 18.44 17.32 15.77 14.38 14.56 13.27 13.37 12.93 13.90 12.91 12.86 13.10 13.70 12.82 13.41 12.80 13.95 15.76 15.08 17.05 16.79 14.50 15.90 14.51 12.43 12.22 11.43 11.19 14.19 14.84 14.38 15.97 15.40 12.47 9.07 10.98 12.80 8.55 8.17
  ]
  set temp-11 [11.42 14.52 12.17 10.10 9.09 12.03 12.75 9.28 10.02 9.03 12.12 9.91 8.88 7.90 8.55 11.41 11.91 12.18 14.28 15.47 16.41 17.58 17.96 17.46 16.33 14.42 11.34 13.71 16.21 14.78 12.56 9.90 7.82 8.42 8.75 13.15 17.35 21.04 18.39 16.15 15.78 13.43 13.83 12.68 11.91 12.10 13.25 14.22 13.71 13.47 14.04 15.10 14.95 14.86 13.75 14.80 12.48 11.76 13.90 17.86 15.65 11.88 13.99 16.80 19.18 15.66 15.58 14.95 14.54 14.12 13.22 13.03 12.25 15.41 16.50 15.25 15.75 14.89 14.31 13.29 14.66 15.70 15.52 14.79 13.89 12.69 18.43 21.32 23.87 20.25 14.36 13.85 13.75 13.88 14.50 14.32 17.57 16.57 16.77 17.09 16.38 16.58 17.84 14.00 14.96 15.95 16.25 16.17 14.79 16.08 17.07 17.23 15.03 14.02 13.01 14.20 14.65 16.79 18.71 15.98 14.74 14.74 15.91 19.66 21.48 19.11 19.67 18.61 16.85 15.01 15.20 14.58 16.28 17.22 15.60 17.67 16.10 15.18 17.15 15.15 16.39 15.70 18.12 18.03 18.05 19.14 17.83 18.41 16.45 13.54 13.16 13.80 14.38 13.00 13.83 19.20 19.68 16.10 14.86 15.03 14.15 16.22 19.33 18.91 16.08 16.55 14.37 13.74 11.11 15.03 12.92 11.82 13.92 15.60 14.90 13.05 13.30 13.48 16.62 16.48 15.25 16.91 16.80
  ]
  set temp-12 [4.31 8.15 7.63 6.72 5.20 5.57 5.53 4.08 8.32 9.93 8.85 8.10 7.20 7.42 6.46 5.33 5.59 7.49 9.44 8.89 7.50 7.97 8.32 9.46 9.57 11.52 11.89 10.50 10.79 13.92 15.35 15.07 13.10 11.18 8.63 7.87 7.80 11.61 14.85 16.68 16.40 9.78 8.34 11.10 9.79 8.75 8.73 13.23 15.37 16.91 19.43 21.30 23.22 21.35 20.34 19.38 20.16 19.08 15.60 13.67 14.59 12.86 10.98 9.40 9.52 11.08 11.71 15.39 15.89 13.00 14.35 14.58 13.64 11.78 11.88 12.74 15.85 15.51 14.66 14.30 16.14 16.62 15.47 15.10 13.79 14.00 14.33 16.14 19.33 20.40 18.43 16.26 14.88 17.47 20.53 20.55 19.82 18.83 18.25 16.63 16.43 15.15 13.92 13.90 14.81 14.07 14.17 15.89 16.77 15.70 14.29 12.98 13.36 17.93 19.94 21.20 19.66 19.42 18.98 16.81 14.95 13.88 18.49 19.26 16.88 17.86 17.62 16.51 15.91 16.29 16.28 14.66 15.22 17.15 18.64 19.98 21.06 20.14 20.16 23.63 25.13 22.69 19.30 18.93 17.29 17.25 17.77 16.93 15.81 18.17 17.22 16.95 14.58 13.16 15.07 17.21 16.40 15.83 14.45 15.60 17.60 18.85 18.72 17.03 12.31 12.82 13.42 14.56 13.48 15.79 14.62 10.07 9.92 12.11 11.97 8.26 12.34 13.66 13.05 12.26 12.23 13.08 11.77
  ]
  set temp-13 [0.91 2.50 2.86 2.68 3.69 4.82 2.71 3.62 6.20 6.90 5.44 6.95 8.04 12.83 14.26 11.68 12.02 14.54 9.20 5.54 6.59 8.12 10.76 12.53 14.17 10.43 6.56 5.56 8.24 8.20 7.91 10.22 11.00 11.25 12.15 13.78 16.03 15.90 14.17 12.30 10.91 10.00 10.53 9.76 11.39 10.22 9.99 9.94 11.58 11.13 11.49 9.13 7.43 7.93 8.56 9.24 11.61 14.13 13.19 12.79 14.88 10.93 11.30 10.40 13.34 14.66 15.83 16.30 13.59 12.06 12.07 13.04 18.05 17.11 14.91 14.32 14.42 15.60 19.32 22.07 19.01 17.32 16.30 14.58 14.48 13.23 12.32 12.73 12.85 14.38 13.73 16.43 15.03 16.90 17.62 17.91 17.15 18.60 17.98 16.47 15.42 14.95 14.37 16.30 16.61 17.19 18.04 19.04 19.88 19.04 18.74 20.86 23.66 24.40 23.03 20.33 20.53 20.76 20.56 19.29 17.97 18.31 21.49 24.77 22.37 18.85 20.89 19.93 15.30 16.09 16.23 17.47 16.11 16.43 15.13 15.18 14.29 19.20 18.83 18.85 15.68 15.23 15.78 17.55 18.05 18.85 18.77 17.82 16.80 17.93 15.94 17.08 17.79 14.34 16.45 18.62 17.41 20.27 21.13 16.31 14.80 13.77 12.90 13.68 15.10 13.86 15.23 13.16 12.55 10.32 11.03 11.36 13.75 12.76 15.53 16.27 14.48 13.92 13.76 9.83 9.83 11.21 10.74
  ]
  set temp-14 [12.05 11.11 12.04 13.39 12.57 11.88 15.24 11.20 9.31 11.15 11.18 8.64 10.60 9.67 6.99 6.85 10.50 8.96 9.11 13.78 12.10 12.45 13.57 13.51 15.08 15.22 12.83 11.76 13.98 14.80 12.72 10.05 8.28 7.76 10.79 13.65 13.51 12.41 12.46 10.76 11.28 11.17 10.60 10.01 9.80 10.78 12.98 15.51 16.86 19.41 18.25 19.19 16.45 15.59 15.77 16.49 16.11 12.73 10.21 12.23 13.38 12.77 13.48 15.76 16.19 13.14 14.48 17.86 20.28 20.05 21.34 18.36 16.20 16.57 15.92 15.80 14.58 16.13 14.47 14.52 14.40 14.58 14.30 14.41 15.65 13.96 15.81 16.05 16.67 15.58 14.44 14.21 14.94 16.60 19.93 20.09 20.18 17.46 16.82 15.39 20.46 21.03 19.59 19.41 19.00 17.22 18.48 20.36 22.38 25.42 24.66 20.49 21.23 22.70 21.44 19.01 20.10 21.13 20.05 21.57 19.49 18.34 19.91 21.35 19.92 19.95 18.47 18.26 18.81 18.72 19.48 18.14 17.76 15.96 16.32 16.88 16.16 15.40 15.43 14.27 12.80 12.42 12.90 13.45 12.29 12.38 12.10 14.20 13.89 15.84 17.53 17.12 15.68 14.83 14.57 15.77 16.80 18.29 18.11 17.62 14.95 15.24 14.91 16.12 15.23 16.30 15.93 15.40 19.11 19.20 18.35 17.21 17.67 16.73 14.65 12.09 13.34 13.31 15.63 13.90 15.15 15.60 16.80
  ]
  set temp-15 [5.88 5.90 6.34 5.70 5.05 7.68 6.95 8.13 9.60 11.32 10.78 8.20 9.29 9.80 12.42 9.93 8.38 8.27 7.63 10.21 9.74 8.15 9.27 10.73 12.55 10.26 8.36 5.11 8.19 8.85 8.65 7.66 10.90 14.26 16.42 11.75 12.06 12.56 14.12 12.09 17.00 15.30 12.88 10.66 8.81 9.64 11.35 10.63 10.30 9.98 11.73 14.10 13.60 10.48 13.17 11.08 12.13 13.01 11.15 10.98 11.39 12.18 13.62 15.09 13.18 19.58 17.77 14.00 12.28 11.42 13.82 15.48 18.18 19.40 14.72 12.27 11.48 13.90 15.27 12.95 12.35 13.44 13.33 11.82 14.08 16.89 18.26 18.66 16.22 17.90 18.23 22.25 26.23 23.04 24.56 21.47 18.49 18.75 17.30 14.26 14.34 18.92 17.83 17.23 18.01 16.80 18.66 20.30 18.80 14.99 16.42 19.91 18.39 17.21 17.17 17.32 14.92 15.28 16.46 14.33 14.38 13.73 14.10 15.87 20.36 18.53 16.67 20.31 19.03 18.96 16.40 19.65 19.13 18.61 19.12 21.86 19.60 16.38 14.63 16.30 16.00 17.54 19.02 19.93 19.61 18.71 17.70 18.21 17.53 15.83 16.27 17.62 20.24 17.75 14.43 12.85 13.12 14.08 12.65 14.17 14.37 12.83 13.20 13.40 14.43 16.52 16.40 12.55 13.47 15.76 13.87 13.80 13.38 14.37 13.33 10.82 12.89 13.09 10.64 10.64 11.75 10.70 11.26
  ]
  set temp-16 [6.16 8.83 12.90 13.73 10.13 8.64 7.50 8.10 8.35 9.98 10.71 11.93 10.54 10.00 10.39 9.63 6.91 7.45 9.96 7.35 7.50 8.01 6.32 4.60 4.93 4.24 5.41 5.02 6.20 8.05 7.33 10.13 11.29 9.13 11.36 15.38 18.82 19.58 19.40 19.39 19.27 18.70 16.35 9.28 7.97 8.33 11.56 12.78 14.50 13.35 15.91 17.94 12.68 10.69 11.59 13.99 14.25 16.41 17.78 17.52 18.74 19.56 17.05 16.26 20.53 19.55 16.28 17.99 15.06 14.12 14.04 14.50 16.58 16.70 15.73 15.07 16.14 15.47 14.91 14.34 15.18 17.20 18.40 21.28 21.10 16.08 14.93 15.10 15.14 16.41 15.70 16.56 15.83 14.76 16.27 16.29 14.89 15.08 16.28 17.06 20.35 18.48 17.64 15.12 14.12 15.59 17.22 19.04 18.66 19.83 24.28 22.20 20.35 19.73 20.78 19.17 17.69 18.50 17.52 18.18 18.75 16.93 15.88 15.62 18.76 17.96 17.80 17.39 16.60 18.96 14.34 13.22 12.23 17.24 17.42 16.69 15.59 15.15 16.17 16.47 17.01 18.85 16.38 17.03 19.83 21.97 23.12 22.36 19.58 20.79 18.79 15.82 17.36 18.28 16.25 17.89 18.09 18.10 17.86 18.85 19.34 19.06 18.04 18.18 20.23 22.00 22.67 21.57 18.82 16.22 16.89 15.23 12.58 16.00 13.13 15.98 13.90 16.53 14.87 13.26 17.48 16.56 14.59
  ]

end
 
 
to set-rad-lists
  
; DATA EELDE  

  set rad-81 [5.85  3.28  6.24  3.58  10.28  14.81  14.62  14.32  18.84  19.27  19.53  10.42  20.39  22.1  21.87  19.12  19.38  15.78  9  18.49  7.73  14.47  19.43  23.75  14.35  15.95  20.31  11.15  6.7  4.56  19.46  19.05  12.14  5.65  7.53  10.6  19.25  14.2  21.63  24.72  24.92  21.27  17.2  7.16  12.66  15.31  14.48  24.73  15.4  22.54  23  14.6  19.34  17.09  15.2  20.35  9.16  15.28  23.84  15.03  17.91  18.05  21.17  22.38  23.38  13.3  20.09  22.46  9.76  17.19  15.62  10.94  16.77  24.65  4.59  5.8  15.48  16.82  8.69  14.88  11.97  19.71  21.17  25  20.73  15.34  5.58  9.49  4.23  1.78  5.8  10.98  12.68  13.63  18.57  18.45  17.33  22.3  26.32  23.6  17.2  8.79  14  13.54  8.78  13.14  11.03  19.54  21.42  16.81  13.98  9.12  14.92  18.23  11.71  10.75  12.59  19.16  18.14  14.15  13.44  24.08  8.1  17.89  25.04  23.85  18.59  19.7  18.77  12.13  4.04  3.27  6.13  20.97  18.02  18.07  11.28  18.3  10.87  13.18  8.56  7.32  9.92  8.74  13.64  14.97  12.39  8.14  4.49  13.52  14.38  17.8  10.33  14.11  15.6  15.22  17.97  18.39  17.44  15.78  12.26  10.32  11.14  13.15  12.68  10.11  5.48  9.77  5.14  5.19  9.62  10.26  5.25  11.3  6.07  11.33  14.1  5.14  4.51  8.62  11.36  11.97  11.4
 
  ]
  set rad-82 [16.25  16.05  12.33  15.24  16.01  10.86  2.65  12.47  14.23  12.12  13.18  13.49  19.64  19.65  20.3  16.41  14.66  19.26  19.1  18  16.3  20.74  12.48  18.92  21.86  20.21  9.06  9.66  12.95  8.32  5.11  16.21  17.93  21.59  8.48  16.38  8.44  11.08  26.33  23.34  24.16  26.05  26.46  24.83  24.23  22.67  15.12  17.32  19.38  8.8  9.34  5.64  11.05  18.74  11.19  24.68  20.7  19.85  29.15  26.71  25.48  24.91  23.07  24.79  22.42  23.63  23.66  24.06  19.85  21.87  21.2  7.85  12.78  21.14  14.46  14.1  8.99  15.96  18.22  10.62  17.6  16.78  14.58  16.59  12.51  15.97  17.92  15.89  13.25  20.22  21.78  13.42  19.75  12  19.45  21.26  8.71  21.97  22.36  27.16  21.38  21.51  26.08  25.6  24.18  21.39  22.15  16.05  21.27  16.27  24.63  15.13  15.71  18.48  13.2  13.48  9.86  15.85  24.86  25.35  24.28  23.01  20.78  23.14  22.22  22.45  11.56  13.52  15.88  9.67  8.89  17.16  19.81  17.61  14.65  19.58  7.54  8.32  13.57  5  16.9  18.06  9.57  6.1  10.95  15.7  15.61  13.16  12.72  15.07  18  14.88  7.57  6.55  15.03  20.02  9.53  12.82  4.6  8.49  13.77  14.65  15.66  11.3  16.74  10.29  14.55  14.06  8.3  9.98  9.27  12.9  9.47  6.48  13.68  14.24  10.13  4.2  4.72  13.44  10.42  11.61  3.47

  ]
  set rad-83 [13.75  9.06  11.6  14.25  6.54  6.82  8.03  5.37  17.19  8.27  7.3  6.95  14.94  10.86  13.22  21.3  6.45  17.22  7.38  17.64  10.22  14  18.1  13.4  12.03  14.92  2.72  14.09  10.44  16.48  6.49  9.13  6.68  10.58  13.89  19.04  4.54  15.54  12.99  21.95  14.9  7.75  15.65  16.9  12.81  10  13.34  9.9  14.58  20.71  4.48  16.07  22.16  3.66  2.07  2.18  7.97  16.76  7.11  18.07  21.47  21.95  14.79  19.88  16.47  21.03  25.83  29.86  22.42  20.26  19.74  24.27  24.84  28.84  15.63  16.5  15.59  26.93  26.29  23.38  28.11  28.93  27.85  23.9  16.57  28.62  25.18  19.15  16.5  5.77  19.96  12.5  14.18  22.83  24.65  27.15  21.4  21.36  20.64  21.13  25.82  27.89  27.69  9.8  24.38  24.82  24  23.76  10.02  8.55  19.01  24.64  27.55  23.78  10.75  20.39  16.32  16.67  14.59  11.57  20.54  24.28  9.8  12.19  20.1  9.26  13.73  5.91  15.87  21.73  22.09  22.88  24.99  10.95  10.27  14.62  22.87  16.26  4.42  20.1  20.61  18.13  16.02  17.51  17.93  11.33  17.86  20.52  7.26  5.9  16.5  21.4  19.26  13.07  9.79  4.78  11.66  4.04  12.89  11.01  10.88  7.73  7.17  8.08  6.31  4.27  7.6  6.74  6.64  8.33  3.8  14.06  11.99  9.82  14.36  14.56  11.72  13.59  12.36  6.43  2.89  11.58  11.57

  ]
  set rad-84 [10.62  15.66  6.18  3.85  3.54  10.75  9.69  3.84  6.22  9.29  14.54  18.94  17.82  19.64  11.88  14.16  20.02  16.26  16.81  14.45  19.04  15.49  23.43  22.49  22.54  23.2  24.46  24.16  22.96  19.68  6.92  14.41  15.27  15.22  19.05  10.77  15.98  23.73  13.98  12.06  10.21  25.62  26.5  23.46  12.36  13.94  3.88  12.78  20.3  11.76  5.56  8.75  3.69  11.18  8.21  6.3  11.34  8.87  5.89  13.45  23.22  16.15  18.16  13.68  8.01  7.07  10.6  4.72  11.31  13.26  11.07  22.18  25.68  7  11.94  9.48  7.66  12.65  17.37  23.87  26.23  20.5  7.3  15.24  15.23  10.58  13.79  10.19  14.85  15.29  16.33  19.73  7.15  12.01  9.39  8.41  11.42  24.34  23.38  25.19  18.46  14.89  16.3  11.54  10.09  13.65  9.72  9.33  4.88  7.62  8.13  14.36  12.97  19.11  14.75  6.82  10.43  11.57  6.29  17.46  21.26  17.32  12.92  10.45  13.93  18.81  10.67  13.95  16.43  20.38  22.88  14.48  8.93  20.03  20.64  18.51  15.03  18.88  21.02  12.77  18.73  19.76  20.99  19.22  18.48  18.13  16.07  9.42  18.17  15.5  8.78  9.64  7.87  5.47  13.91  8.14  5.84  7.92  16.41  2.15  9.65  6.09  10.43  6.27  13.66  12.71  4.74  2.31  12.39  12.12  9.63  5.99  5.3  8.92  7.51  7.52  5.27  4.49  8.89  11.28  10.06  9.04  5.93

  ]
  set rad-85 [6.38  5.05  7.11  14.97  3.9  14.26  7.81  4.78  5.27  6.09  6.82  4.8  11.26  6.99  14.32  8.02  11.4  15.68  19.05  12.07  20.56  23.18  12.97  22.82  16.22  16.15  11.75  12.04  12.8  20.42  13.73  8.37  9.58  6.32  8.26  17.4  13.41  19.51  20.98  5.19  13.22  18.24  9.21  15.17  22.2  13.62  25.65  20.86  24.87  19.57  19.42  2.64  3.65  16.46  18.07  25.32  23.7  17.92  20.82  26.23  26.36  27.21  28.01  25.76  26.64  10.57  6.04  6.91  16.69  10.07  12.81  12.74  10.36  13.05  12.63  13.77  17.86  12.75  15.13  17.33  13.08  20.88  16.63  12.64  11.34  13.28  6.9  8.79  9.52  6.97  13.21  12.49  21.36  28.43  28.56  27.23  10.3  25.27  11.03  9.16  12.2  18.45  15.28  24.42  21.27  19.29  8.15  20.31  16.47  11.51  11.06  23.32  6.68  18.76  25.1  17.47  11.73  10.26  12.51  9.36  4.71  9.16  6.71  8.63  14.04  13.13  11.23  16.77  18.93  18.67  21.6  7.94  20.65  19.93  22.12  19.42  16.34  13.95  11.23  12.15  5.9  14.01  14.49  10.2  9.57  6.51  13.85  12.49  18.12  20.14  12.04  17.33  7.29  12.02  10.7  7.03  11.78  5.12  14.92  12.31  4.79  13.23  10.05  14.09  15.55  6.62  7.81  9.19  7.07  9.57  13.12  12.83  3.98  6.89  3.19  6.49  5.94  7.25  12.88  10.9  9.17  12.5  11.39

  ]
  set rad-86 [6.89  12.98  8.59  13.3  15.58  19.71  2.89  2.3  7.83  8.92  18.8  21.13  13.28  7.69  7.02  10.06  12.02  11.23  9.49  10.14  13.46  17.9  18.43  16.19  16.43  15.31  11.87  10.91  9.92  20.09  24.92  22.9  22.45  13.75  17.14  12.17  17.75  15.66  18.36  4.42  7.36  14.79  17.05  16.61  9.12  25.46  24.15  17.43  23.52  24.98  21.73  20.51  8.17  15.52  24.18  27.53  12.11  23.69  18.15  23.77  23.29  6.45  22.54  11.19  15.98  4.94  5.45  7.87  11.28  21.39  27.47  20.43  25.28  29.39  29.7  29.24  27.07  17.25  17.5  25.01  23.55  10.02  29.68  29.94  13.6  20.97  25.91  26.68  28.9  28.3  28.54  26.33  24.46  21.6  19.34  5.98  13.11  18.63  19.29  16.95  16.63  21.97  14.95  19.33  15.89  16.68  22.47  13.62  11.95  14.48  12.46  15.17  4.8  18.4  18.02  6.2  15.13  20.87  15.61  10.82  16.95  17.06  22.52  16.58  23  9.4  16.74  24.38  17.92  9.83  11.09  22.23  21.52  18.55  12.93  18.43  17.97  16.63  16.1  15.91  8.41  12.46  6.33  7.24  17.55  14.6  18.14  6.22  3.44  10.94  9.68  13.13  11.41  6.9  8.07  6.12  13.13  11.28  7.75  13.95  14.45  15.02  5.14  12.94  13.4  17.45  5.95  5.91  11.81  8.61  11.94  11.21  13.9  11.4  3.81  9.52  12.92  13.68  6.34  6.3  10.79  7.89  3.03

  ]
  set rad-87 [16.44  12.42  14.55  9.22  5.51  7.52  15.17  8.59  10.34  8.39  10.59  5.48  12.6  3.98  15  6.67  15.91  17.18  11.46  3.62  20.36  18.3  20.99  20.05  18.01  22.32  24.17  23.78  21.54  17.07  5.56  13.2  8.54  9.24  11.88  16.52  16.65  19.86  24.43  18.75  9.33  5.31  15.57  11.43  8.68  12.5  11.31  16.68  22.71  12.15  15.2  14.65  26.25  28.37  28.48  28.62  26.33  7.97  14.47  7.21  11.42  12.01  20.52  6.15  12.42  7.88  11.17  18.6  8.71  6.68  20.47  16.42  22.48  14.03  20.41  16.41  15.02  19.7  8.17  6.7  6.41  21.06  13.42  11.61  9.26  19.43  8.07  11.73  7.27  12.83  18.92  24.5  20.53  25.78  28.8  27.65  27.71  25.3  14.95  17.88  13.65  11.99  18.71  20.24  27.15  12.82  18.6  8.76  16.92  22.74  14.73  15.08  18.08  10.56  8.15  19.05  16.98  6.26  12.99  7.37  15.09  8.3  11.32  18.8  11.46  17.83  18.58  16.06  11.58  9.04  12.03  17.52  19.28  4.21  6.16  13.34  18.02  5.6  17.67  6.27  6.94  18.45  19.83  14.82  13.9  12.19  8.62  5.82  5.69  10.89  5.64  13.94  11.67  18.45  15.09  13.56  6.32  13.6  13.42  11.93  16.33  15.46  5.2  14.01  6.93  4.15  15.61  13.58  7.43  5.3  11.16  12.68  6.85  8.52  6.15  10.07  8.05  9.07  13.47  10.49  9.36  9.93  13.05

  ]
  set rad-88 [12.39  14.94  10.01  8.09  7.32  17.81  13.85  7.9  11.82  13.94  11.37  12.64  19.1  20.93  21.09  9.11  7.25  19.15  14.54  9.89  9.74  19.37  18.13  24.84  18.84  20.03  20.35  6.04  13.93  17.08  12.79  18.69  11.4  9.97  15.82  20.53  24.37  7.46  16.67  21.98  26.05  23.36  24.16  24.57  25.16  24.69  19.66  14.26  14.92  14.02  22.45  26.45  27.54  18.73  24.47  20.69  13.21  11.87  15.11  17.1  9.79  15.92  13.29  20.31  15.81  16.48  12.76  4.04  4.23  2.78  10.53  9.78  29.72  29.65  16.66  9.99  9.15  18.24  14.42  11.63  10.62  19.79  21.11  13.59  7.76  8.68  8.5  9.76  13.86  10.24  20.13  11.88  18.7  15.65  17.09  6.41  18.17  16.82  15.42  12.73  21.6  16.25  16.31  7.2  8.86  11.08  12.21  10.48  7.73  11.99  9.81  6.07  4.25  10.83  13.28  21.58  7.24  15.9  20.26  18.17  19.61  16.96  18.61  19.22  18.13  10.9  15.55  19.7  18.56  22.11  17.49  16.31  12.12  12.51  12.97  21.05  13.82  15.69  19.18  19.61  7.49  13.4  7.24  11.25  15.82  10.42  11.04  11.54  6.04  15.42  14.71  15.86  14.32  6.61  10.4  9.73  15.87  6.62  17.26  16.47  17.08  15.8  9.12  6.05  6.96  11.91  12.7  10.19  5.02  6.38  5.07  6.96  4.67  3.76  10.85  5.76  7.94  11.4  3.21  2.95  6.47  7.98  12.58

  ]
  set rad-89 [8.74  13.23  18.35  7.78  4.62  3.36  7.82  13.7  17.75  7.21  13.43  4.1  3.33  3.66  7.15  4.78  19.48  6.35  17.15  14.84  9.18  15.29  10.48  4.33  7.37  5.68  13.99  16.74  15.82  18.13  21.24  19.27  23.87  24.97  17.72  16.27  16.55  24.62  22.39  24.4  12.03  11.33  13.14  18.22  18.28  18.79  16.71  23.82  23.32  26.55  27.63  29.27  29.1  28.21  27.89  23.8  29.21  25.99  21.16  18.72  18.62  12.25  19.6  21.67  5.54  14.56  25.21  14.22  22.18  14.61  21.67  22.92  26.99  29.07  28.07  25.46  29.68  30.25  29.35  29.83  29.84  21.53  22.36  20.52  18.99  27.46  28.62  19.47  16.96  6.41  26.14  6.38  16  28.86  27.82  27.66  26  24.82  13.66  7.36  10.45  10.02  14.91  15.08  16.81  12.06  20.22  13  19.01  20.02  12.5  25.95  15.06  8.03  11.41  8.19  17.45  19.97  11.94  15.03  9.87  17.83  16.74  13.92  9.24  14.05  17.38  22.43  7.1  7.96  18.57  20.29  5.31  8.98  20.3  14.9  14.69  14.59  18.48  20.78  19.75  21.33  15.53  17  17.91  10.63  13.46  14.33  5.71  15.37  10.43  4.13  6.78  15.39  9.45  10.6  10.74  15.89  9.76  16.84  16.21  15.22  8.28  9.88  15.91  5.11  12.64  12.23  10  11.62  14  4.39  15.57  13.25  12.96  6.76  4.67  5.89  10.81  12.73  6.75  7.25  4.08

  ]
  set rad-90 [17.22  15.44  10.82  10.63  12.39  18.79  18.2  20.03  20.68  10.13  13.51  5.7  10.79  10.34  7.94  13.83  13.59  15.73  16.54  5.86  18.97  18.85  19.04  19.46  18.55  14.3  15.69  16.8  14.46  22.43  24.22  24.28  24.92  24.48  24.01  23.66  21.38  22.22  17.77  13.01  9.65  6.48  10.5  5.92  20.73  21.46  14.42  10.66  19.05  23.35  24.15  22.18  26.79  21.94  21.47  17.27  21.13  17.67  28.63  16.4  16.5  21.24  15.08  12.74  5.03  13.26  15.95  12.82  12.56  17.96  9.18  5.98  5.41  9.54  9.47  8.6  14.42  18.5  21.71  14.73  9.39  19.6  13.07  18.42  22.88  7.11  19.62  16.06  20.12  22.4  16.88  18.7  17.17  20.61  16.22  11.56  5.17  7.77  4.09  12.22  14.92  24.02  24.05  26.81  27.48  28.27  17.91  8.83  9.11  23.57  25.6  22.18  21.29  18.55  7.68  9.32  20.72  25.79  19.87  13.88  24.3  22.98  24.39  25.63  25.19  22.52  16.41  16.22  19.97  12  10.37  9.65  18.65  17.19  20.78  17.6  14.19  15.32  10.96  6.78  16.42  10.85  5.18  10.42  15.23  20.9  18.84  10.31  18.1  16.65  16.25  5.4  6.7  5.81  4.32  2.9  7.71  13.51  4.59  9.26  9.5  8.85  5.61  9.94  11.44  13.58  13.28  6.1  16.15  6.92  6.94  4.67  7.16  10.64  5.82  8.97  7.84  8.44  8.14  6.97  7.22  9.47  3.76

  ]
  set rad-91 [5.81  2.63  9.87  16.32  14.53  13.71  11.25  12.35  18.46  16.82  18.18  20.06  18.84  18.16  19.42  10.61  18.6  10.55  17.28  18.59  16.46  10.1  15.29  17.66  18.09  18.62  11.9  11.18  8.86  16.28  6.16  3.43  9.61  9.28  5.73  4.98  9.11  23.29  23.57  18.85  21.52  12.56  9.71  17.5  13.57  15.94  18.26  22.78  22.03  12.84  12.88  21.56  20.09  23.88  14.24  8.56  6.2  9.72  14.02  23.04  8.7  21.28  21.96  6  15.88  22.99  18.26  13.76  8.66  10.43  13.88  13.06  5.4  18.6  19.13  5.99  9.45  13.34  17.17  8.97  17.2  22.95  21.37  17.98  18.35  7.01  12.95  7.44  10.02  9.34  13.59  10.7  23.24  26.05  29.09  27.21  28.78  27.7  20.32  11.56  22.72  25.66  20.72  12.29  19.7  9.25  15.05  18.92  10.92  9.68  15.58  20.72  21.38  23.53  8  18.01  17.51  21.04  24.82  25.96  25.15  13.41  16.02  23.01  17.22  21.97  17.09  18.89  14.19  15.24  19.49  6.88  5.89  17.26  16.45  16.08  20.22  16.32  12.49  15.77  15.44  15.41  20.88  18.67  18.87  14.96  14.8  11.17  14.03  15.6  20.3  20.37  19.85  19.27  18.61  18.59  18.28  5.67  8.43  7.08  9.88  6.59  14.09  10.12  13.32  16.84  16.08  4.33  8.49  6.85  7.44  11.54  11.63  14.57  6.83  7.93  3.7  2.6  2.85  5.22  11.14  5.15  4.54

  ]
  set rad-92 [2.18  11.49  4.38  9.8  11.99  7.86  15.13  18.15  19.05  18.43  18.06  14.56  10.75  6.1  6.55  6.22  4.64  4.81  15.39  18.2  15.74  12.38  6.52  9.6  13.74  8.99  14.54  6.82  13.65  16.08  4.68  13.91  13.14  24.26  20.66  21.16  9.27  11.28  9.54  16.58  11.6  8.12  14.26  26.26  24.28  26.88  24.24  26.32  27.3  27.03  26.78  25.96  26.81  26.02  27.1  27.76  26.98  27.18  26.79  22.7  20.86  19.23  15.67  8.98  3.8  17.5  22.27  16.11  21.1  17.86  27.57  27.89  19.42  25.86  22.41  27.42  20.74  26.1  14.35  12  27.55  22.21  20.7  9.75  20.52  24.87  28.04  23.02  26.22  24.9  25.61  16.16  17.83  22.01  10.9  10.77  25.82  27.02  27.31  22.62  17.05  12.71  14.63  8.95  18.4  18.19  15.42  8.1  18.85  25.26  21.97  16.88  21.79  25.51  16.27  13.04  18.34  12.22  20.69  24.54  18.87  22.07  18.73  15.58  12.95  19.24  23.47  15.44  23.16  17.93  21.78  11.99  16.8  9.89  11.21  15.24  18.19  10.15  8.31  11.48  13.67  6.75  14.82  16.07  18.54  10.71  10.13  12.93  9.49  6.1  5.16  9.92  13.59  13.28  7.43  5.66  11.77  14.01  16.62  8.98  12.91  12.35  15.87  13.16  12.26  7.81  11.42  12.97  7.56  15.18  10.98  4.4  10.83  8.95  10.94  8.97  10.1  11.44  12.53  12.22  11.97  5.15  4.12

  ]
  set rad-93 [9.5  5.28  2.85  9.14  9.72  4.11  5.72  8.97  15.47  12.13  16.55  4.76  14.56  14.39  15.68  18.22  4.96  4.35  8.42  16.59  16.23  13.17  15.7  15.11  17.53  16.25  22.8  21  20.71  21.15  21.56  4.38  20.27  20.82  23.07  23.3  9.1  21.14  22.71  20.14  23.37  23.24  14.44  11.6  9.52  21.7  26.66  15.98  12  18.41  17.32  17.84  26.6  19.26  25.89  15.85  4.33  4.23  20.5  17.72  18.01  16.53  16.5  10.09  28.12  21.16  22.99  23.16  23.56  28.26  25.67  20.31  12.24  14.41  12.37  21.61  7.18  18.82  8.04  13.22  23.08  17.67  16.87  11.39  17.05  17.88  12.76  17.32  17.06  24.94  28.14  28.24  26.73  19.6  17.64  12.2  14.12  12.72  15.5  12.82  20.89  15.92  14.75  14.48  5.61  15.31  6.91  12.66  20.44  12.86  9.11  14.27  13.12  7.7  12.74  19.26  18.19  6.19  11.79  6.77  4.77  11.6  12.6  16.31  13.42  11.74  11.71  9.17  12.32  15.88  6.08  14.1  8.33  5.19  21.94  21.2  6.51  12.28  20.3  21.36  20.18  4.89  10.53  3.01  14.31  17.11  9.91  14.7  10.29  12.02  14.02  7.85  9.38  11  4.56  7.94  10.78  17.21  9.9  16.44  3.55  9.89  7.19  10.09  13.36  2.49  6.1  9.02  2.9  8.98  12.47  15.73  12.56  6.86  5.44  6.92  8.89  1.22  2.52  2.98  10.69  11.82  7.91

  ]
  
  ; DATA MARKNESSE
  
  set rad-94 [5.96 13.39 15.54 5.48 8.23 13.64 13.76 7.31 10.91 7.99 19.53 10.93 14.48 10.2 3.96 19.07 11.24 16.98 10.07 16.81 6.78 19.02 18.91 16.1 9.54 5.98 6.38 6.35 20.33 20.19 9.46 19.75 24.28 17.89 19.23 6.74 12.24 5.97 6.9 11.76 18.38 25.75 25.3 24.65 7.64 11.17 6.18 14.07 18.49 19.06 10.15 7.15 11.48 11.7 10.3 7.22 9.15 14.72 18.51 18.33 26.14 28.04 9.3 10.71 10.08 21.62 12.66 5.54 7.44 19.2 16.59 23.97 23.44 19.01 26.57 19.53 7.61 19.69 9.13 11.13 11.42 10.52 13.81 28.49 28.38 19.14 20.09 21.31 24.6 18.83 26.66 28.52 24.69 25.83 14.36 19.45 19.02 6.86 24.13 22.41 26.26 26.28 26.69 22.22 19.02 25.16 20.16 26.24 28.6 27.37 26.8 25.83 22.04 24.08 22.78 20.22 23.95 19.95 13.8 17.97 21.96 22.46 14.81 21.81 22.8 21.58 15.68 17.97 16.4 21.45 19.3 11.62 10.67 4.59 18.01 14.18 17.56 21.65 12.23 10.87 10.56 15.01 20.02 16.4 6.51 13.66 17.41 10.7 6.42 18.04 16.49 11.84 14.5 12.08 8.95 11.97 6.96 13.11 10.82 5.58 10.88 9 10.61 12.19 7.25 15.62 4.4 1.95 4.15 4.87 10.01 10.54 6.72 13.71 13.78 14.04 10.28 12.08 8.7 4.9 11.95 4.05 6.44
  ]
  set rad-95 [4.37 16.65 7.32 14.67 12.53 6.91 8.39 12.8 7.39 3.69 11.95 12.32 14.21 10.39 4.85 11.55 5.02 9.1 20.69 14.02 17.49 13.11 12.79 20.72 19.75 18.42 7.29 8.83 18.9 13.73 23.11 22.49 22.75 22.66 21.51 22.07 23.32 11.39 9.46 13.21 11.34 15.3 17.73 18.65 20.5 21.54 6.74 8.36 15.2 17.81 17.26 26.05 20.43 22.42 17.87 21.97 21.57 14.8 22.19 19.24 22.26 19.94 10.65 18.47 13.11 19.11 8.58 7.36 16.93 5.89 10.42 12.53 18.3 21.91 8.04 5.49 6.6 6.67 21.55 23.27 20.13 16.91 18.39 15.53 22.42 27.01 29.06 29.16 28.37 28.59 26.49 24.05 25.79 5.31 11.79 26.06 24.15 25.85 25.89 23.37 24.6 26.45 23.7 27.1 19.24 19.55 23.04 18.28 6.18 15.63 20.96 23.16 23.4 24.35 24.21 26.89 26.54 11.34 11.47 19.6 24.87 25.06 25.4 25.65 23.8 16.98 21.88 20.11 13.24 17.86 23.58 24.42 24.29 21.84 14.58 14.58 14.83 18.58 22.36 21.37 20.2 21.4 17.15 17.67 17.12 15.1 9.82 16.46 9.34 13.88 11.86 17.83 18.98 15.86 3.64 16.09 7.53 13.37 11.62 7.34 3.98 3.38 12.88 7.16 14.09 4.77 11.67 9.18 15.04 15.99 12.94 13.45 11.7 8.58 8.27 8.5 11.41 11.08 1.94 5.91 10.31 13.07 8.96
  ]
  set rad-96 [17.44 11.76 17.16 19.02 16.37 6.82 15.73 6.28 7.45 3.8 3.3 15.97 17.78 19.23 21.28 19.2 20.37 18.17 15.93 15.95 21.49 17.34 8.99 16.47 19.83 13.31 17.3 19.77 10.51 19.26 14.99 4.68 4.57 15.81 16.35 25.02 26.12 22.69 23.61 7.68 7.45 6.56 4.52 10.24 10.51 18.7 6.39 6.56 15.52 26.72 25.46 12.22 9.88 13.36 7.31 25.2 5.21 19.75 12.41 23.06 25.37 21.53 23.76 17.22 24.39 27.38 27.59 26.18 20.84 5.9 23.99 26.27 25.26 24.96 16.55 26.05 27.1 29.35 25.27 7.41 16.81 11.35 11.28 9.65 8.14 6.43 17.65 13.25 14.15 9.02 7.25 18.42 14.24 16.18 16.56 17.72 8.38 20.97 17.13 20.83 17.97 20.19 18.61 11.13 8.54 20.88 21.44 23.31 11.19 24.23 25.19 26.3 23.77 15.38 8.26 11.87 21.47 8.46 19.83 16.29 13.56 7.89 13.9 19.09 15.55 24.2 25.43 14.99 9.48 19.68 18.18 11.17 10.55 11.31 8.73 14.93 13.27 7.42 11.8 20.74 21.58 22.09 11.18 16.31 14.33 16.68 13.72 19.57 15.07 3.94 3.06 12.43 14.73 11.89 17.37 18.91 9.68 18.67 13.84 16.33 15.02 15.67 7.63 7.81 11.58 10.57 6.45 7.27 10.54 17.31 12.5 8.06 13.11 14.17 2.23 9.75 10.5 11.4 12.03 8.05 7.87 1.83 7.21
  ]
  set rad-97 [18.36 4.99 9.59 13.91 2.77 16.86 18.93 18.34 17.38 18.05 11.71 12.93 12.75 6.6 16.77 11.05 21.33 14.77 10.49 16.88 22.87 11.77 22.95 18.09 6.06 15.71 9.23 4.31 3.04 10.91 19.86 24.01 20.86 9.18 8.1 6.85 18.76 14.37 10.38 15.73 10.75 19.72 24.92 5.12 20.02 22.14 23.9 20.33 15.99 19.36 7.12 7.93 22.08 21.68 23.98 19.21 8.9 15.14 22.04 28.58 28.49 28.43 30.13 29.67 25.04 27.18 26.85 22.55 5 23.91 29.12 12.02 17.28 17.92 14.03 10.41 24.59 27.49 22.51 23.28 14.39 15.89 15.18 10.54 13.1 17.37 7.35 14.72 20.12 14.94 6.55 17.63 20.41 20.21 17.93 16.83 12 16.43 19.18 15.98 24.06 27.4 26.21 19.24 21.21 20.85 13.95 9.46 12.35 23.21 23.95 11.59 19.86 18.12 12.99 10.58 20.41 9.5 20.53 24.61 13.9 12.61 18.45 19.7 19.91 20.65 22.48 25.53 25.16 24.76 22.31 22.41 24.2 23.08 22.21 11.15 15.85 17.4 20.11 20.82 22.15 18.2 16.3 4.81 9.39 18.11 15 7.1 12.47 4.25 13.38 6.2 14.53 16.08 12.44 15.33 11.52 11.98 13.2 11.45 7.44 12.1 12.33 10.2 10.85 14.51 15.7 12.6 15.92 6.55 13.39 14.36 14.26 16.36 15.79 9.26 4.78 14.56 13.31 10.48 9.47 7.53 7.44
  ]
  set rad-98 [7.15 4.05 4.93 7.2 11.08 10.13 12.45 6.31 9.95 9.18 12.24 13.53 9.59 10.77 5.53 16.1 14.15 5.96 18.08 3.85 16.39 19.54 20.38 8.23 7.74 8.23 10.98 12.18 17.59 9.7 10.54 18.38 9.94 21.52 12.83 7.73 6.73 23.06 23.27 24.08 22.06 24.19 24.57 27.83 27.61 28 27.62 22.86 26.75 16.72 11.63 13.94 8.97 8.09 12.23 10.35 14.72 18.95 11.82 10.32 19.61 22.44 19.79 17.52 10.25 14.39 13.31 7.56 16.7 4.51 15.76 9.81 14.02 23.41 11.94 17.35 12.29 14.93 11.62 8.85 25.75 25.8 24.9 8.24 8.93 13.45 22.22 13.83 19.91 19.21 7.88 17.75 12.73 10.52 10.76 7.57 15.26 16.42 13.59 7.47 15 15.52 5.8 18.93 8.36 15.65 10.23 16.09 21.45 23.76 25.84 11.03 22.65 15.75 21.04 25.75 24 20.88 8.28 8.04 12.24 11.51 15.8 12.01 22.11 19.21 11.72 23.45 21 24 24.77 24.79 22.15 20.78 12.71 9.41 11.36 19.34 18.24 16.04 17.79 17.99 7.28 13.07 13.45 10.87 11.7 4.13 17.29 11.41 10.84 12.1 20.92 8.86 8.73 3.26 10.23 5.38 8.62 9.2 8.12 5.39 12.83 9.59 3.45 7.71 3.45 7.86 8.44 5.68 11.77 5.07 7.74 12.93 13.61 9.57 13.56 10.05 11.1 12.6 8.01 6.75 4.85
  ]
  set rad-99 [16.6 17.06 8.54 3.55 4.07 4.88 11.56 8.59 4.34 4.36 11.98 8.31 12.08 14.4 12.62 17.97 12.54 19.83 19.83 21.3 18.26 10.06 19.51 16.81 15.98 20.93 21.28 24 24.1 25.11 22.24 23.01 24.25 21.05 14.52 2.51 16.99 19.21 21.49 10.75 17.68 18.04 20.67 14.35 19.06 18.67 25.5 27.91 23.55 13.82 22.34 17.69 15.44 7.03 21.49 24.97 27.99 21.98 26.27 14.41 16.75 22.83 16.92 16.7 10.5 12.14 15.25 17.97 18.83 25.19 19.56 16.4 13.88 24.21 22.57 22.18 27.4 22.16 23.34 30.2 8.84 22.46 24.06 15.35 20.79 27.76 29.87 15.58 20.41 8.85 13.83 12.2 13.29 20.5 17.91 6.96 17.5 22.13 19.71 27.65 26.11 28.06 24.66 18.94 15.37 20.76 26.13 16.26 24.63 20.2 15.17 13.28 6.03 12.03 24.82 17.64 19.02 24.88 27.13 27.15 26.26 24.98 24.87 25.42 23.02 18.77 14.25 23.98 4.75 11.2 15.41 8.62 11.46 19.37 12.91 8.86 20.28 15.29 10.43 13.87 10.47 9.31 17.76 14.87 15.63 19.75 14.32 13.19 16.63 17.1 18.45 14.36 9.21 3.96 14.78 18.15 13.53 17.18 14.74 12.71 12.79 12.78 13.79 15.54 14.51 12.76 7.01 7.29 11.59 6.19 12.08 9.83 3.91 9.85 7.41 9.73 11.04 9.87 7.41 3.52 6.79 7.97 5.68
  ]
  set rad-00 [6.29 10.44 13.84 7.45 9.84 12.47 20.44 12.65 19.61 20.85 19.69 7.28 9.5 13.07 7.52 13.94 12.09 17.65 17.95 14.57 16.04 6.25 3.35 14.5 21.65 20.81 13.96 19.49 3.89 5.13 11.42 6.04 7.91 16.97 24.75 24.68 25.07 19.86 21.45 22.8 24.9 25.19 27.81 26.72 25.35 23.51 10.08 16.08 11.85 17.71 9.99 13.11 14.29 19.36 13.35 18.05 14.22 7.66 16.5 18.93 27.23 8.53 19.7 21.47 21.07 12.18 7.97 15.76 29.54 28.07 22.85 28.15 20.65 12.68 10.35 20.76 24.35 29.21 28.84 29.67 28.29 18.55 13.45 14.9 13.66 12.11 18.76 24.26 19.13 15.15 16.69 10.74 18.45 20.97 24.07 8.66 22.83 15.4 14.13 5.97 16.54 13.75 21.61 12.33 12.06 15.42 10.6 9.09 11.48 13.53 24.13 25.65 16.36 12.88 22.92 13.88 14.08 15.03 17.24 18.99 19.21 21.6 21.62 17.18 20.12 16.91 17.87 17.94 14.93 15.49 18.8 7.56 12.15 18.73 20.58 14.58 13.56 17.54 20.24 17.08 11.92 16.05 11.47 16.01 18.92 22.14 12.95 20.23 5.29 11.32 14.25 15.91 18.89 7.75 10.34 9.09 14.72 13.02 3.72 11.54 2.45 6.36 11.74 16.95 7.59 5.73 10.73 9.52 9.33 5.18 8.83 12.44 1.78 5.3 10.64 13.59 14.79 11.2 2.94 10.67 3.57 8.29 8.95
  ]
  set rad-01 [12.38 17.18 14.36 7.75 13.05 10.03 10.83 11.36 9.1 10.7 15.74 15.24 16.97 10.26 7.17 8.77 8.62 13.4 16.67 12.83 17.18 17.68 16.42 16.02 6.03 9.88 13.62 13.28 21.9 19.05 11.99 22.13 9.57 11.18 19.79 18.33 26.26 19.66 24.84 26.61 27.08 27.56 26.61 16.17 15.36 11.24 16.12 12.07 22.86 20.13 23.12 28.35 28.81 28.45 29.54 22.28 9.87 5.82 25.31 28.66 16.15 16.37 6.65 12.77 13.63 20.14 24.12 23.36 23.69 25.68 21.65 26.54 23.43 19.79 26.72 18.99 17.95 11.82 15.58 22.42 21.67 24.92 18.38 17.11 26.72 28 27.82 13.67 23.89 22.39 15.5 26.57 17.71 22.03 27.82 28.81 24.63 16.74 10.9 19.21 15.88 13.27 19.13 19.05 9.32 15.98 25.05 23.98 17.14 14.03 16.58 9.81 23.04 15.63 24.09 26.43 25.99 20.15 19.95 24.52 22.92 19.18 20.61 21.87 13.89 17.51 17.4 12.58 12.78 14.04 12.4 14.26 19.61 5.75 4.42 19.01 21.32 11.9 19.12 11.45 15.34 13.74 19.3 18.28 15.87 14.54 18.46 14.43 18.06 14.1 16.24 12.24 7.2 12.49 3.3 5.45 9.39 12.16 11.37 6.37 13.11 13.25 8.95 4.49 9.28 11.43 10.34 9.14 9.49 5.33 6.81 4.72 2.31 10.42 6.47 11.64 9.77 9.98 11.06 8.23 11.82 10.43 10.23
  ]
  set rad-02 [14.99 17.45 18.63 18.78 19.67 20.5 16.33 19.47 9.03 16.1 13.57 14.69 9.67 8.66 2.08 4 12.96 9.59 17.8 6.89 18.98 17.38 18.66 15.74 16.72 5.26 13.64 5.61 13.17 6.72 15.51 11.3 14.85 6.47 4.24 12.75 19.95 15.7 18.89 15.79 5.56 12.83 24.02 14.57 17.91 26.41 26.94 10.04 16.46 16.97 24.67 8.09 17.74 15.19 15 13.23 19.85 14.89 15.81 20.17 21.06 25.92 28.06 21.02 21.51 16.53 11.65 11.76 18.04 22.81 11.83 17.14 12.36 7.53 14.1 21.52 12.41 27.32 25.05 24.04 7.93 16.34 14.54 24.18 27.4 25.41 22.17 21.93 14.8 20.41 8.79 5.76 16.24 6.91 21.64 13.96 12.52 9.76 21.52 16.38 5.12 17.12 18.91 7.31 25.65 27.28 23.73 21.55 17.38 10.46 20.85 15.17 13.66 9.99 17.5 17.32 16.96 25.08 23.94 25.8 22.64 17.58 5.13 21.02 9.84 16.79 11.69 15.16 19.02 18.56 17.66 5.74 9.74 13.06 21.35 14.48 21.71 22.02 23.22 21.91 10.22 14.2 3.66 5.68 11.45 4.88 16.76 17.7 15.18 15.95 15.64 10.39 11.38 14.83 19.12 20.27 18.29 16.97 9.42 10.98 13.35 14.32 3.15 8.6 18.04 17.8 6.57 12.14 8.22 6.19 6.72 5.06 5.31 6.87 10.3 14.43 14.31 8.32 8.56 11.65 9.83 6.95 14.17
  ]
  set rad-03 [8.24 10.9 15.13 6.64 11.55 17.15 20.4 13.13 16.39 10.42 18.61 19.93 19.65 20.67 21.36 21.27 21.65 22.17 13.79 17.78 20.53 13.94 21.11 21.55 13.7 4.44 14.14 10.7 20.6 7.96 11.53 15.11 14.61 24.35 6.67 12.44 24.55 22.91 11 24.74 21.34 13.5 17.01 15.13 24.74 23.65 11.56 15.29 9.79 14.64 14.63 6.85 8.24 7.61 9.02 24.97 25.32 27.68 26.5 25.33 26.55 26.85 19.95 22.44 21.49 19.63 27.24 23.89 13.6 27.75 13.55 24.03 17.97 25.27 21.78 27.7 22.53 22.93 21.48 7.89 18.19 21.25 17.39 19.47 22.21 19.55 27.52 26.8 10.39 22.21 14.49 10.72 13.23 13.25 7.38 10.36 6.82 23.11 21.58 21.34 28.07 20.81 23.7 27.7 28.84 28.37 27.42 9.37 13.92 26.67 21.69 22.92 25.57 24.25 11 19.95 16.52 14.77 18.35 23.14 13.17 22.39 19.29 18.84 24.03 25.5 22.2 22.08 21.08 21.55 15.05 22.17 19.64 20.65 19.21 21.04 20.67 13.96 14.38 15.42 15.86 15.47 16.19 7.83 16.79 10.11 17.34 14.18 9.53 8.52 5.27 17.75 14.03 14.6 15.14 11.59 18.75 18.08 6.56 11.43 5.44 12.26 5.14 9.21 6.4 16.25 17.69 14.29 13.75 14.69 15.22 11.66 14.18 14.71 13.1 11 14.31 14.71 11.73 10.4 4.47 10.25 10.36
  ]
  set rad-04 [16.76 12.61 7.77 11.2 10.91 10.46 9.34 7.59 10.87 9.25 8.13 11.25 13.69 18.27 19.09 20.39 17.73 12.48 12.29 19.53 13.55 14.34 19.9 18.84 19.89 20 21.42 17.06 10.26 21.06 18.22 6.83 19.3 13.79 19.44 15.12 2.33 9.96 15.85 8.55 16.33 11.58 7.4 19.35 23.2 22.61 26.78 27.38 27.19 20.67 21.11 20.63 25.04 23.55 16.75 14.78 12.53 28.85 28.66 16.92 7.94 25.85 7.8 15.14 9.87 10.92 20.15 26.67 26.45 20.87 15.69 21.92 17.12 16.96 20.78 17.21 18.48 13.29 13.27 22.13 16.97 18.67 26.68 12.89 4.57 14.23 24.96 16.3 25.12 20.44 17.35 16.94 12.98 20.55 16.48 23.33 28.06 26.23 13.31 13.59 19.39 16.18 10.69 14.69 11.72 11.81 9.45 22.14 13.12 20.02 8.24 16.61 22.37 17.14 22.66 7.6 18.29 20.95 25.36 25.67 21.84 21.67 17.05 22.83 23.12 20.57 18.5 22 16.71 22.89 23.26 16.46 11.42 11.83 4.39 17.66 15.4 8.96 20.09 15.09 11.16 6.81 10.89 16.83 10.68 8.94 13.26 12.2 3.75 17.05 12.79 9.81 13.65 18.84 18.85 17.66 17.13 16.62 17.99 17.96 18.56 17.39 17.56 11.21 14.67 7 11.58 12.16 14.02 13.72 8.43 15.54 2.78 9.53 5.04 6.78 7.47 6.28 11.02 11.79 4.52 8.94 9.38
  ]
  set rad-05 [18.28 18.51 16.62 14.42 15.82 8.8 10.5 11.28 12.88 9.35 19.64 17.02 5.58 7.23 14.99 7.78 6.83 8.12 3.63 15.09 21.94 22.56 22.63 21.05 21.25 12.87 15 17.24 12 8.15 20.62 13.02 9.13 8.06 12.46 14 11.1 16.01 18.79 15.82 13.76 19.31 26.96 27.02 17.66 10.93 12.54 26.74 20.85 14.11 21.45 24.42 22.23 12.25 21.59 24.08 26.15 26.71 22.6 7.84 19.98 27.09 9.82 15.89 15.07 12.39 17 15.56 22.66 28.72 13.53 13.27 14.45 19.29 28.4 25.22 15.08 10.99 26.59 30.16 27.06 23.44 28.04 29.21 27.43 15.56 27.97 29.77 29.48 14.58 9.49 11 14.15 19.78 12.02 15.11 11.28 19.38 8.43 10.66 26.58 20.19 24.43 25.67 25.12 20.07 22.31 17.59 18.82 18.95 15.19 5.71 9.12 9.59 17.94 9.01 9.19 7.49 18.34 13.2 15.52 8.24 18.47 14.39 16.04 22.43 6.16 10.97 20.3 16.71 10.76 12.94 10.63 6.65 13.97 12.7 8.61 17.03 21.29 22.46 13.33 10.73 12.49 8.67 11.39 16.4 14.65 18.52 15.06 16.74 20.55 20.07 19.78 12.67 13.78 17.85 19.14 19.11 16.7 14.08 17.01 12.84 11.31 4.33 14.01 15.63 4.44 6.01 12.54 11.03 12.79 15.98 14.65 14.34 14.31 13.76 10.64 9.12 8.04 3.22 10.81 10.16 2.85
  ]
  set rad-06 [11.2 9.4 11.12 15.3 15.71 12.1 16.42 10.93 15.18 13.24 11.34 10.49 11.33 18.25 14.54 14.78 16.11 13.3 13.17 12.6 15.87 12.29 12.85 13.01 19.41 12.56 21.3 15.7 11.67 12.23 10.95 22.12 19.88 22.22 21.42 24.16 21.51 22.34 23.7 26.04 22.98 24.63 20.4 25.22 17.06 15.93 19.93 18.2 6.16 8.73 9.44 13 8.91 15.52 9.03 9.04 6.01 16.81 16.82 19.77 10.36 13.46 21.78 22.36 25.5 16.88 26.96 22.47 29.25 28.17 29.2 29.54 30.15 28.64 15.52 3.83 10.58 26.12 23.67 22.51 18.62 7.77 13.68 25.03 23.7 11.19 5.48 10.53 18.33 28.8 28.92 29.17 29.13 29.05 28.59 22.85 20.03 24.11 22.45 16.8 24.12 15.55 28.87 26.78 27.85 28.31 28.45 28.23 27.69 27.08 21.91 25.24 16.83 17.91 19.17 24.32 24.46 17.84 15.58 20.55 13.98 12.9 10.62 14.17 9.48 13.32 20.02 21.91 13.11 11.26 7.49 10.68 11.78 9.35 17.38 8.84 14.53 15.78 17.02 10.78 18.48 7.87 13.1 13.55 10.46 13.68 12.8 12.99 13.97 8.5 13.63 12.26 6.44 11.06 8.48 6.31 12.44 5.61 16.09 12.64 16.53 18.36 18.82 17.06 16.48 15.69 14.79 15.91 12.86 9.85 8.04 7.77 15.38 15.59 13.73 7.13 6.66 6.91 4.19 10.14 9.13 8.68 11.1
  ]
  set rad-07 [17.82 17.35 11.76 19.11 18.76 15.92 14.99 19.27 13.32 9.89 10.26 19.47 14.88 20.81 21.74 20.89 16.22 15.26 21.4 12.92 21.88 22.59 15.66 11.86 18.73 19.47 22.59 22.71 24.39 25.22 25.45 25.69 21.99 23.33 24.44 16.64 6.79 15.22 16.38 18.67 7.59 14.84 13.63 13.27 25.65 13.53 19.52 20.89 25.5 22.88 10.07 8.39 26.39 27.69 25.37 13.24 10.42 10.22 5.91 27.72 12.33 24.35 24.2 10.26 18.7 19.1 18.69 22.74 26.87 22.76 15.35 27.25 8.33 12.28 11.47 8.98 14.88 13.61 13.19 25.37 22.39 10.64 15.44 13.71 17.11 10.43 9.58 18.65 21.79 10.06 21.74 16.91 16.72 13.01 13 19.35 7.44 19.4 26.6 18.92 24.9 9.93 14.32 19.26 18.8 13.31 18.14 16.84 24.09 22.29 13.38 21.28 15.21 14.62 10.19 24.38 12.15 21.62 16.02 12.19 19.54 19.77 25.05 13.53 23.64 25.59 25.23 22.82 12.08 17.81 7.15 13.27 21.06 22.75 16.41 17.16 13.01 12.86 14.05 16.65 14.3 12.8 10.31 16.94 14.31 19.42 20.11 16.74 11.4 14.97 15.36 6.97 6.46 13.46 10.68 15.69 15.02 6.03 13.99 13.01 9.16 8.29 10.1 8.49 7.64 8.1 5.88 15.88 14.34 3.57 12.75 12.91 4.38 6.68 7.83 14.05 6.63 9.15 5.67 11.43 4.4 2.27 6.2
  ]
  set rad-08 [6.4 13.44 7.15 5.06 14.05 17.25 18.35 18.24 19.66 12.26 11.13 16.14 15.3 11.96 15.14 14.89 21.51 11.49 19.14 14.66 22.23 22.8 20.77 16.19 19.21 16.61 17.69 5.07 13.01 14.8 14.04 23.3 19.76 24.66 26.07 25.77 25.84 26.17 26.18 26.13 26.64 25.41 24.05 23.96 22.8 8.71 3.88 21.34 19.28 22.82 28 24.69 23.76 27.34 8.53 8.2 12.03 12.15 8.55 14.6 11.19 14.59 25.72 12.07 14.47 13.51 26.61 20.75 22.49 27.93 24.14 15.51 11.28 16.33 20.46 15.48 16.86 28.9 17.53 12.61 26.96 19.7 19.36 16.16 28.38 20.19 27.37 21.38 15.85 23.43 26.86 28.47 25.28 8.06 23.5 25.52 19.5 16.34 11.76 20.06 5.7 15.22 18.18 21.05 27.08 7.24 18.83 10.89 12.72 9.03 16.12 11.19 19.94 16.12 25.08 19.35 17.52 16.11 19.13 12.23 24.77 23.25 15.98 16.39 12.72 18.58 22.9 21.29 9.3 14.25 18.87 13.06 10.51 12.24 13.81 18.51 19.8 19.98 12.28 8 10.51 10.17 9.59 9.25 11.52 13.35 14.65 4.82 3.26 9.95 15.43 19.46 18.96 13.22 4.89 7.22 12.12 8.46 10.27 5.97 12.14 17.71 14.45 14.45 9.12 14.07 15.85 14.16 11.58 11.01 15.76 12.52 14.72 7.78 8.7 3.53 5.97 13.93 13.4 13.58 8.84 5.39 3.96
  ]
  set rad-09 [15.33 18.54 17.72 5.36 14.84 17.15 9.75 7.07 7.98 16.66 13.59 11.39 14.9 17.57 20.05 14.63 14.13 22.69 20.68 21.64 21.26 22.06 21.98 22.31 20 13.24 15.88 5.91 16.73 19.29 22.02 20.24 9.51 17.86 9.79 5.47 11.32 15.41 21.66 24.46 22.69 28.09 27.61 10.71 6.62 16.38 9.71 17.08 17.7 26.09 16.58 20.01 22.49 26.99 24.82 8.55 16.92 22.68 29.84 28.54 27.01 28.46 29.65 15.19 19.2 17.17 20.11 15.2 19.61 15.54 19.97 13.66 26.21 29.52 21.65 18.22 21.43 26.07 25.29 20.05 17.12 17.1 19.22 30.23 29.67 28.08 16.58 17 19.29 24.12 27.15 23.24 27.01 18.4 25.21 26.64 23.8 16.84 13.11 16.81 9.62 16.35 8.76 18.3 22.74 22.05 27.41 14.11 12.43 20.33 24.09 20.04 14.47 9.82 17.25 20.63 22.87 17.38 20.91 16.96 20.55 20.82 19.85 7.72 15.69 23.07 24.17 23.49 19.81 5.67 9.56 19.18 14.03 9.83 19.73 18.55 22.33 20.86 15.02 22.08 20.05 18.57 16.34 20.62 21.67 21.53 5.63 15.55 9.46 14.08 15.45 12.72 11.85 8.39 12.21 9.07 16.6 14.73 10.64 14.77 17.71 7.94 13.63 10.39 13.36 10.5 13.54 6.67 14.71 8.47 15.53 14.78 9.63 13.55 12.91 10.45 10.86 5.87 11.97 12.48 7.31 3.53 2.78
  ]
  set rad-10 [10.01 15.76 7.23 8.96 13.37 17.4 17.12 13.18 18.58 15.12 7.84 19.4 19.91 20.08 21.17 17.35 22.43 23.02 20.41 16.15 16.35 16.09 23.87 20.91 19.57 15.27 20.12 20.58 18.41 10.53 9.36 7.65 2.75 17.18 22.7 22.41 7.56 6.68 6.79 12.46 14.37 8.84 5.22 13.16 17.32 23.24 23.21 20.11 28.32 27.89 23.19 28.25 26.6 25.4 24.6 18.6 15.54 22.64 22.2 6.29 12.48 20.93 26.71 29.95 29.11 28.23 15.54 3.96 17.95 9.29 8.61 9.11 23.2 18.17 23.76 25.55 24.55 30.35 13.02 16.85 12.15 20.03 26.37 29.22 28.38 22.92 29.61 29.81 29 21.85 15.58 23.01 25.67 19.06 27.06 21.4 28.25 26.42 24.65 26.3 26.16 22.95 15.16 20.1 25.35 16.96 19.34 19.27 25.16 27.33 22.51 18.42 18.23 23.81 25.27 21.37 11.01 18.47 17.89 15.33 21.88 8.63 18.13 8.69 21.01 8.74 14.63 23.15 9.06 11.54 20.92 13.86 21.93 13.58 17.88 20.71 16.24 11.45 3.8 10.51 21.2 19.3 11.91 9.51 7.42 19.38 15.39 3.36 6.15 13.42 9.63 15.27 15.46 11.01 8.38 14.86 16.58 19.17 19.54 5.09 6.65 12.72 7.24 14.21 5.31 14.05 3.49 13.24 9.53 12.8 10.68 3.82 4.69 10.19 12.91 10.59 9.92 13.89 9.41 1.61 3.41 12.22 3.24
  ]
  set rad-11 [5.38 16.58 5.08 17.24 4.64 7.34 13.24 19.99 18.61 19.28 19.06 15.42 18.36 12.7 16.48 13.65 17.38 20.15 21.5 21.61 20.43 21.13 21.52 21.88 23.55 21.56 17.3 17.57 20.68 23.03 25.9 25.08 23.71 19.73 24.43 22.18 22.55 22.77 10.42 13.79 24.66 17.7 24.02 17.92 20.86 5.32 6.24 10.58 11.86 24.59 26.34 13.39 27.02 19.44 27.79 13.81 10 13.09 8.49 26.04 10.13 27.89 28.67 25.9 28.97 12.65 12.89 15.37 16 23.86 21.44 20.34 27.5 12.42 22.97 15.26 6.62 18.17 14.61 8.48 21.31 16.88 9.48 15.18 22.1 8.73 21.24 29.56 20.24 12.55 22.78 20.04 20.21 12.08 18.79 23.64 15.98 18.51 20.43 15.16 22.92 23.51 21.08 2.96 5.51 16.96 12.37 18.35 7.9 20.16 11.1 21 16.1 10.73 5.14 11.68 7 16.7 20.67 11.36 8.57 9.43 23.23 23.39 8.82 20.01 18.61 15.22 17.82 12.93 15.48 11.81 5.12 10.3 7.13 9 20.82 13.47 18.36 9.23 16.25 18.06 10.89 16.08 6.92 6.47 16.05 5.52 13.73 7.88 8.22 14.13 11.63 9.22 17.92 17.29 8.14 11.91 5.02 10.87 6.58 8.58 11.63 9.54 5.17 12.23 8.26 14.59 14.08 5.91 8.01 12.06 5.77 4.63 14.21 13.95 13.07 13.01 11.11 10.05 13.85 13.54 13.57
  ]
  set rad-12 [11.77 12.46 9.42 3.34 9.3 15.12 11.84 17.12 3.94 6.24 16.26 13.86 11.43 16.76 11.67 18.78 12.83 14.4 13.17 13.82 11.63 10.41 13.89 11.1 13.11 12.07 15.72 4.85 7.6 20.68 16.27 21.32 5.66 1.67 8.48 11.39 16.68 5.71 9.77 7.17 13.28 20.14 21.67 21.78 11.87 22.89 19.32 18.22 21.48 23.89 20.95 25.73 26.43 26.47 28.6 29.19 27.46 28.24 20.11 17.84 6.7 9.78 26.99 8.31 6.4 20.36 10.44 17.3 19.46 8.8 23.9 19 14.99 20.44 17.08 8.95 18.79 22.86 15.83 15.51 20.44 10.72 19.49 21.96 8.1 16.33 22.23 11.04 18.3 16.02 24.4 16.87 22.15 22.8 19.02 14.05 15.22 24.64 8.23 13.19 16.33 13.87 16.87 11.34 11.05 15.83 16.61 14.76 9.11 15.18 24.2 15.85 23.33 26.44 26.54 25.31 25.51 18.98 12.74 18.82 22.18 9.56 23.75 13.86 22.41 20.75 18.18 10.99 11.09 16.88 19.57 22.27 18.05 24.91 20.48 18.27 21.57 18.92 18.96 21.68 21.12 18.33 14.03 17.13 19.81 13.19 10.87 9.32 17.44 13.09 19.58 17.67 7.64 20.34 14.06 17.03 18.34 12.27 11.5 12.21 14.85 18.12 10.12 7.7 10.04 12.16 5.17 12.96 10.6 11.99 9.06 12.84 7.6 6.83 13.45 10.35 5.68 10.84 6.89 7.64 10.86 12.02 12.9
  ]
  set rad-13 [18.16 19.73 17.73 8.37 15.11 13.36 18.39 16.55 12.98 7.62 3.56 5.59 11.57 9.19 10.97 12.88 12.67 21.82 10.74 23.01 16.46 20.06 11.87 21.42 14.3 4.51 16.93 23.95 18.92 17.77 25.88 17.43 23.52 25.52 23.31 22.33 22.38 12.12 21.18 12.86 8.07 16.01 11.23 14 9.12 7.13 4.36 4.95 9.41 3.25 3.13 9.51 16.29 21.94 17.19 10.09 26.38 27.07 9.85 10.63 25.6 6.62 28.71 18.57 28.2 27.05 25.33 28.21 28.04 16.19 17.43 21.29 11.48 9.44 20.03 21.07 22.52 19.79 22.33 11.34 8.79 4.53 11.37 12.72 14.21 15.33 25.75 11.18 9.88 20.39 20.18 17.73 23.14 8.29 17.6 17.46 27.17 26.87 27.17 27.41 14.55 12 12.13 20.72 18.57 26.69 20.42 19.56 26.28 24.57 16.73 26.91 25.33 22.98 15.39 19.05 10.96 13.43 16.82 21.13 13.55 17.35 21.8 24.05 20.02 24.41 20.93 15.05 7.24 20.8 14.38 13.63 17.97 15.77 18.04 22.84 11.53 17.25 14.77 15.22 6.87 16.38 17.53 13 18.84 14.88 14.23 20.81 19.92 17.49 16.43 15.38 15.07 10.18 3.8 10.8 15.77 17.87 13.17 3.77 10.72 12.04 8.5 9.91 10.8 11.83 4.74 11.23 13.22 10.88 12.09 8.59 8.6 7.38 7.39 6.72 4.73 6.04 9.11 14.62 13.9 13.96 12.95
  ]
  set rad-14 [12.79 15.77 15.95 4.59 12.46 5.37 10.82 10.93 12.54 9.51 16.05 16.88 13.93 15.73 15.57 22.2 16.15 13.57 21.26 21.08 5.66 17.95 14.02 19.18 19.01 14.45 3.72 6.24 13.5 19.9 7.81 9.4 20.02 15.02 20.7 11.46 16.56 6.42 9.93 5.15 8.2 10.87 19.38 14.93 17.39 26.61 25.29 27.01 26.83 21.87 16.09 18.31 9.77 18.3 25.75 16.27 14.18 4.46 8.71 21.4 28.16 21.5 25.12 25.86 15.15 12.81 26.88 21.11 17.75 21.97 21.76 26.37 24.2 21.35 19.71 22.56 14.39 20.53 14.17 7.93 17.2 18.82 16.86 22.55 19.17 21.19 23.3 11.58 18.05 16.81 14.08 20.75 21.34 27.24 25.31 11.42 15.58 21.51 9.23 4.78 23.39 21.57 25.73 19.78 15.28 11.45 26.58 25.24 25.05 23.63 20.03 4.39 23.4 26.91 23.68 7.5 17.24 20.41 14.03 21.52 19.3 21.44 19.24 17.6 20.46 22.73 22.95 11.58 17.72 14.93 18.68 8.2 17.36 13.33 21.08 19.16 17.46 12.41 6.88 10.67 13.66 11.57 14.69 6.55 13.87 16.67 7.91 16.64 21.7 13.03 15.96 11.93 14.35 16.23 7.77 16.93 18.07 12.31 5.24 12.58 16.13 8.16 6.86 13.1 16.06 14.05 11.26 9.42 13.75 15.04 15.18 11.41 9.23 10.43 11.53 8.89 3.07 8.25 4.16 11.33 10.38 6.93 8.86
  ]
  set rad-15 [12.57 13.29 13.09 12.61 18.62 13.66 11.89 11.43 17.95 18.08 7.63 19.5 15.58 19.57 21.07 18.26 15.93 22.18 17.07 22.97 22.66 13.5 20.03 21.56 6.49 6.2 21.27 16.21 14.54 17.7 16.45 21.7 10.72 14.91 16.43 15.55 20.9 19.14 11.94 23.94 22.38 16.56 23.57 13.89 22.25 11.05 21.7 8.71 15.58 21.43 22.94 21.98 16.61 29.09 15.69 15.01 15.92 15.87 11.95 21.52 9.06 19 5.38 13.86 29.09 28.37 27.71 28.63 26.01 15.41 22.11 29.76 29.72 14.95 6.01 24.23 16.89 20.52 14.78 17.15 12.92 9.14 17.41 8.26 18.4 26.99 18.55 21 16.14 25.08 29.32 29.38 27.11 25.91 25.14 17.12 28.01 16.6 14.29 19.55 26.68 24.1 9.35 6.79 11.58 8.7 24.01 22.19 24.85 10.33 19.5 24.95 26.63 21.18 16.19 9.17 19.42 9.76 12.72 17.61 19.97 18.46 24.13 24.41 24.99 7.73 22.33 22.53 22.45 24.13 24.19 9.85 14.57 11.6 21.82 17.73 11.19 4.79 2.24 6.92 15.67 21.22 20.24 19.22 21.57 13.95 15.46 12.72 5.73 15.49 18.28 16.81 14.82 10.33 12.75 14.05 7.47 13.56 12.71 9.85 10.12 16.94 17.9 17.67 9.94 12.8 8.19 8.33 4.53 3.59 11.36 12.54 7.6 7.81 5.01 12.45 3.5 11.7 9.87 11.18 6.22 13.96 13.94
  ]
  set rad-16 [17.99 8.89 12.87 9.71 6.23 7.28 12.12 13.59 13.94 15.38 21.01 18.35 15.05 14.04 8.5 13.38 16.91 16.73 19.78 21.11 23.73 18.88 17.23 18.02 11.68 14.52 16.5 13.76 10.15 18.48 23.26 22.61 22.33 17.4 26.26 25.87 25.51 26.58 26.61 16.65 23.11 25.61 26.2 17.61 16.24 16.73 18.02 16.52 17.52 7.99 18.05 9.37 4.09 5.46 7.48 17.06 24.72 22.92 19.8 18.89 20.29 20.8 12.9 17.2 24.17 27.37 28.3 27.5 20.3 28.08 23.97 14.59 14.03 14.44 13.17 15.86 24.39 19.91 17.62 19.42 5.98 19.83 22.4 15.17 15.1 11.11 19.58 12.13 20.66 16.67 9.86 6.63 22.48 20.62 26.62 11.64 23.2 23.89 8.28 17.97 22.95 12.31 15.08 12.42 13.73 23.79 9.3 24.88 26.99 28.17 26.18 23.68 15.38 15.79 20.35 12.01 20.45 14.93 11.95 14.46 16.64 12.84 17.41 13.57 7.68 12.64 20.23 17.44 13.27 18.18 16.82 22.03 6.64 7.19 11.49 16.37 16.9 15.06 23.18 23.83 19.84 15.9 10.68 6.79 18.16 21.76 21.53 18.2 18.16 12.45 14.93 18.53 19.96 17.15 12.71 14.65 11.19 16.99 17.6 17.8 17.92 16.18 17.26 8.32 17.11 16.36 16.41 15.77 7.77 6.85 11.15 8.92 9.16 14.32 10.51 12.09 13.9 13.79 10.05 14.28 11.95 3.12 10.92
  ]
  
end
    


   
@#$#@#$#@
GRAPHICS-WINDOW
138
10
537
418
-1
-1
2.925
1
10
1
1
1
0
0
0
1
0
132
0
128
0
0
1
ticks
30.0

BUTTON
5
10
135
43
NIL
load-map
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
5
296
134
329
keep-seed?
keep-seed?
1
1
-1000

INPUTBOX
5
331
134
391
seed-for-random
2122000105
1
0
Number

SLIDER
5
101
135
134
frac-res-fields_
frac-res-fields_
0
1
0.1
0.05
1
NIL
HORIZONTAL

BUTTON
5
45
68
78
Go
Go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
70
45
135
78
Go-once
Go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
697
10
1147
222
Mean yield (ton/ha)
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Sus.fields" 1.0 0 -13345367 true "" "plot mean-yield-sus-std"
"Sus.fields+fungicides" 1.0 0 -2674135 true "" "plot mean-yield-sus-fungi"
"Res.fields" 1.0 0 -13840069 true "" "plot mean-yield-res"

MONITOR
541
59
619
104
Blight-days
blight-day-counter
17
1
11

MONITOR
541
11
591
56
NIL
day
17
1
11

MONITOR
593
11
643
56
NIL
month
17
1
11

MONITOR
645
11
695
56
year
year-counter
17
1
11

MONITOR
543
128
692
173
Yield sus.-no fungi
mean-yield-sus-std
1
1
11

MONITOR
543
175
692
220
Yield sus.-fungi
mean-yield-sus-fungi
1
1
11

MONITOR
543
223
692
268
Yield res
mean-yield-res
1
1
11

TEXTBOX
545
109
695
127
Yield (ton/ha)
11
0.0
1

TEXTBOX
545
275
695
293
Phytophthora
11
0.0
1

MONITOR
542
291
693
336
Disease incidence (%)
infected-tot>1%
1
1
11

SWITCH
5
238
134
271
carry-over?
carry-over?
0
1
-1000

MONITOR
541
340
692
385
Infected resistant fields (%)
infected-res>0%
1
1
11

PLOT
697
422
1029
619
Resistance breakdown (Infected resistant fields,%)
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -10141563 true "" "plot infected-res>0%"

PLOT
697
223
1027
420
Disease incidence (%)
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -8990512 true "" "plot infected-tot>1%"

PLOT
1035
421
1331
619
Initial infections (no)
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Wild type" 1.0 0 -13840069 true "" "plot initial-inf-patches-0"
"Virulent strain" 1.0 0 -2674135 true "" "plot initial-inf-patches-1"

SLIDER
5
171
135
204
frac-res-fungicides_
frac-res-fungicides_
0
1
0
0.05
1
NIL
HORIZONTAL

SLIDER
5
136
135
169
frac-sus-fungicides_
frac-sus-fungicides_
0
1
0.9
0.05
1
NIL
HORIZONTAL

TEXTBOX
8
86
129
104
Potato fields
11
0.0
1

TEXTBOX
16
432
166
450
Crop parameters
11
0.0
1

TEXTBOX
235
429
385
447
Late blight parameters
11
0.0
1

SLIDER
6
622
131
655
max-lai-susceptible
max-lai-susceptible
3
6
5
1
1
NIL
HORIZONTAL

SLIDER
6
657
131
690
max-lai-resistant
max-lai-resistant
3
6
5
1
1
NIL
HORIZONTAL

SLIDER
6
516
131
549
lai-initial
lai-initial
0.03
0.1
0.05
0.01
1
NIL
HORIZONTAL

SLIDER
5
692
130
725
lue-sus
lue-sus
0.0008
0.0012
0.0010
0.0001
1
NIL
HORIZONTAL

SLIDER
5
727
131
760
lue-res
lue-res
0.00064
0.001
8.0E-4
0.00002
1
NIL
HORIZONTAL

SLIDER
6
586
132
619
rd-lai
rd-lai
0.005
0.015
0.01
0.001
1
NIL
HORIZONTAL

SLIDER
6
551
132
584
rg-lai
rg-lai
0.01
0.02
0.015
0.001
1
NIL
HORIZONTAL

SLIDER
6
446
132
479
crop-emergence-avg
crop-emergence-avg
1
50
31
1
1
NIL
HORIZONTAL

SLIDER
6
481
131
514
harvest-date
harvest-date
150
183
183
1
1
NIL
HORIZONTAL

SLIDER
294
587
436
620
wind-speed_
wind-speed_
1
5
3
0.2
1
NIL
HORIZONTAL

SLIDER
149
446
289
479
frac-initial-infected
frac-initial-infected
0
0.04
0.02
0.002
1
NIL
HORIZONTAL

SLIDER
149
481
289
514
initial-inf-surface-area
initial-inf-surface-area
0.004
0.02
0.01
0.002
1
NIL
HORIZONTAL

SLIDER
148
586
289
619
mutfrac
mutfrac
1E-8
1E-6
1.0E-7
1E-8
1
NIL
HORIZONTAL

SLIDER
295
446
436
479
lesion-size
lesion-size
0.00001
0.0002
1.0E-4
0.00001
1
NIL
HORIZONTAL

TEXTBOX
7
207
143
235
Carry over effects virulent strain between years?
11
0.0
1

SLIDER
148
551
289
584
si
si
2.3E08
9.2E08
460000000
2E6
1
NIL
HORIZONTAL

SLIDER
295
482
437
515
spore-survival
spore-survival
0.1
0.3
0.2
0.01
1
NIL
HORIZONTAL

SLIDER
294
552
436
585
cur-eff
cur-eff
0.01
0.2
0.1
0.01
1
NIL
HORIZONTAL

SLIDER
294
517
436
550
dep-eff
dep-eff
0.01
0.2
0.1
0.01
1
NIL
HORIZONTAL

SLIDER
149
516
289
549
rg-lesions
rg-lesions
0.01
0.2
0.1
0.01
1
NIL
HORIZONTAL

SLIDER
147
621
289
654
inf-efficiency-std
inf-efficiency-std
0.015
0.045
0.03
0.002
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

The model represents an agricultural landscape with potato fields. Data of a Dutch agricultural region is used as input for the model. The model simulates potato production, disease spread and pathogen evolution at the landscape level. A susceptible and late blight resistant potato variety are distinguished in the model. The resistant variety has a potentially lower yield but cannot get infected with the disease. However, during the growing season virulent spores can emerge as a result of mutations during spore production. This new virulent strain is able to infect the resistant fields, resulting in resistance breakdown. The model shows how disease severity, resistance durability and potato yield are affected by the fraction of resistant fields in the landscape.

## HOW IT WORKS

The time step in the model is one day and the model simulates the growing season from April to September for 36 years. Weather data is used as input for the model. Crop and disease processes start on May 1 (day of crop emergence). Infections are initialised in a fraction of the potato fields, randomly selected. At the start of the simulation only the wild type is present, and during the season the virulent strain can emerge as result of mutations. Processes on crop growth include leaf area development and tuber growth. Processes related to late blight include lesion expansion, spore production and spore dispersal. When the infection level in a field reaches 5% the potato haulm is destroyed according to governmental regulations. On a fraction of the potato fields fungicides are applied which slows down the infection in a field. 

## HOW TO USE IT

Click the 'Load map' button to initialise the landscape. Click the 'Go' button to start te simulation. 

## THINGS TO TRY

The management strategies of potato fields can be adjusted with sliders including the fraction of potato fields with the resistant potato variety and the fraction of susceptible and resistant fields with fungicide application. Furthermore the model can be run with two different settings: with and without carry over effects of the virulent strain between years. In this way years can be analysed independently but also in a time series to analyse resistance durability over longer time periods. A number of sliders are shown related to parameters on crop growth and late blight dispersal.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Fraction resistant fieds-short term dynamics" repetitions="10" runMetricsEveryStep="false">
    <setup>load-map</setup>
    <go>go</go>
    <enumeratedValueSet variable="rd-lai">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rg-lesions">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="winter-survival">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lue-sus">
      <value value="0.0010"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lai-initial">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutfrac">
      <value value="1.0E-7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lesion-size">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="si">
      <value value="460000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-lai-susceptible">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="frac-res-fields_">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="crop-emergence-avg">
      <value value="31"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-inf-surface-area">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="frac-sus-fungicides_">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="harvest-date">
      <value value="183"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spore-survival">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="inf-efficiency-std">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wind-speed_">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-lai-resistant">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="frac-initial-infected">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dep-eff">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="frac-res-fungicides_">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cur-eff">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rg-lai">
      <value value="0.015"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed-for-random">
      <value value="-38711006"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-seed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lue-res">
      <value value="8.0E-4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Fraction resistant fieds-long term dynamics" repetitions="10" runMetricsEveryStep="false">
    <setup>load-map</setup>
    <go>go</go>
    <enumeratedValueSet variable="rd-lai">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rg-lesions">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="winter-survival">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lue-sus">
      <value value="0.0010"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lai-initial">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutfrac">
      <value value="1.0E-7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lesion-size">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="si">
      <value value="460000000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-lai-susceptible">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="frac-res-fields_">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="0.95"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="crop-emergence-avg">
      <value value="31"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-inf-surface-area">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="frac-sus-fungicides_">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="harvest-date">
      <value value="183"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spore-survival">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="inf-efficiency-std">
      <value value="0.03"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="wind-speed_">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-lai-resistant">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="frac-initial-infected">
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dep-eff">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="frac-res-fungicides_">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cur-eff">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="rg-lai">
      <value value="0.015"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed-for-random">
      <value value="-38711006"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-seed?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="lue-res">
      <value value="8.0E-4"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
